@@ -20,7 +20,6 @@
  */
 
 #include "about.h"
-#include "gui_logo.h"
 #include "i18n.h"
 #include "options_prefs.h"
 #include "stock_icons.h"
@@ -668,17 +667,16 @@ gui_create_about (GtkWidget *vbox_top, GUI *appGUI)
     GtkWidget *label;
     GtkWidget *hseparator;
     GtkWidget *logo_area;
-    GdkPixbuf *logo, *logo_scaled = NULL;
+    GdkPixbuf *logo;
     GtkWidget *viewport;
     GtkWidget *hbuttonbox = NULL;
     GSList    *radiobutton_group = NULL;
-    char *str;
+    gchar *str, *filename;
 
     appGUI->about_counter = 0;
     appGUI->about_vbox = GTK_BOX (vbox_top);
 
     logo_area = gtk_image_new ();
-    logo = gdk_pixbuf_new_from_inline (-1, osmo_logo, FALSE, NULL);
     gtk_widget_show (logo_area);
     gtk_box_pack_start (GTK_BOX (vbox_top), logo_area, FALSE, TRUE, 0);
 
@@ -701,15 +699,12 @@ gui_create_about (GtkWidget *vbox_top, GUI *appGUI)
     gtk_widget_show (label);
     gtk_box_pack_start (GTK_BOX (vbox_top), label, FALSE, TRUE, 4);
 
-    if (logo_scaled != NULL) {
-        gtk_image_set_from_pixbuf (GTK_IMAGE (logo_area), logo_scaled);
-        g_object_unref (logo_scaled);
-    } else {
-        gtk_image_set_from_pixbuf (GTK_IMAGE (logo_area), logo);
-        g_object_unref (logo);
-    }
-
+    filename = g_strdup_printf(PIXMAPSDIR G_DIR_SEPARATOR_S "osmo_logo.png");
+    logo = gdk_pixbuf_new_from_file(filename, NULL);
+    g_free(filename);
 
+    gtk_image_set_from_pixbuf(GTK_IMAGE(logo_area), logo);
+    g_object_unref(logo);
     /*--------------------------------------------------------------------------*/
 
     vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 4);
