@@ -24,7 +24,7 @@
 
 #include "gui.h"
 
-#define     OSMO_WEBSITE        "http://clayo.org/osmo"
+#define     OSMO_WEBSITE        "http://osmo-pim.sourceforge.net"
 #define     MAILING_LIST        "http://sourceforge.net/p/osmo-pim/mailman"
 #define     BUG_TRACKER         "http://sourceforge.net/p/osmo-pim/bugs"
 #define     FEATURE_REQUESTS    "http://sourceforge.net/p/osmo-pim/feature-requests"
