@@ -19,7 +19,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-
+#include <config.h>
 #include <stdio.h>
 #include <string.h>
 #include <sys/stat.h>
@@ -43,53 +43,76 @@
 
 /*------------------------------------------------------------------------------*/
 
-int
-tar_archive (const gchar *outname, GUI *appGUI)
-{
-	struct archive *archive;
-	struct archive_entry *entry;
-	struct stat st;
-	gchar buff[8192];
-	gint len;
-	gint fd;
-	gint i = 0;
-	gchar *filename = NULL;
-
-	archive = archive_write_new ();
-	archive_write_set_format_ustar (archive);
-	if (archive_write_open_filename (archive, outname) != ARCHIVE_OK)
-	{
-		g_printf ("%s\n", archive_error_string (archive));
-		return archive_errno (archive);
-	}
-
-	while ((filename = g_slist_nth_data (appGUI->file_list, i)) != NULL)
-	{
-		stat (filename, &st);
-		entry = archive_entry_new ();
-		archive_entry_copy_stat (entry, &st);
-		archive_entry_set_pathname (entry, filename);
-		archive_write_header (archive, entry);
-		fd = open (filename, O_RDONLY);
-		len = read (fd, buff, sizeof (buff));
-		while (len > 0)
-		{
-			archive_write_data (archive, buff, len);
-			len = read (fd, buff, sizeof (buff));
-		}
-		close (fd);
-		archive_entry_free (entry);
-		i++;
-	}
-
-	archive_write_free (archive);
-
-	return ARCHIVE_OK;
+static struct archive *
+create_archive(const gchar *filename) {
+    struct archive *archive;
+    archive = archive_write_new();
+    archive_write_set_format_ustar(archive);
+    if (archive_write_open_filename(archive, filename) != ARCHIVE_OK) {
+        fprintf(stderr, "%s\n", archive_error_string(archive));
+        archive_write_free (archive);
+        return NULL;
+    }
+    return archive;
 }
 
+static void
+close_archive(struct archive *archive) {
+    archive_write_free (archive);
+}
+
+static void
+add_entry_to_archive(struct archive *archive, gchar *filename, gchar *archive_entry_name) {
+    struct archive_entry *entry;
+    struct stat st;
+    gchar buff[8192];
+    gint fd;
+    gint len;
+
+    stat(filename, &st);
+    entry = archive_entry_new();
+    archive_entry_copy_stat(entry, &st);
+    archive_entry_set_pathname(entry, archive_entry_name);
+    archive_write_header(archive, entry);
+    fd = open(filename, O_RDONLY);
+    len = read(fd, buff, sizeof (buff));
+    while (len > 0) {
+        archive_write_data(archive, buff, len);
+        len = read(fd, buff, sizeof (buff));
+    }
+    close(fd);
+    archive_entry_free(entry);
+}
+
+static void
+add_to_archive(gchar *from_dir, gchar *extension, gchar *prefix, struct archive *archive) {
+    const gchar *item_name;
+    GDir *dir_path = g_dir_open(from_dir, 0, NULL);
+    g_return_if_fail(dir_path != NULL);
+
+    while ((item_name = g_dir_read_name(dir_path)) != NULL) {
+        gchar *source_filename = g_build_filename(from_dir, item_name, NULL);
+        gchar *target_filename;
+        if (!g_file_test(source_filename, G_FILE_TEST_IS_REGULAR)) {
+            g_free(source_filename);
+            continue;
+        }
+
+        if (!g_str_has_suffix(item_name, extension)) {
+            g_free(source_filename);
+            continue;
+        }
+        target_filename = g_build_filename(prefix, item_name, NULL);
+        add_entry_to_archive(archive, source_filename, target_filename);
+        
+        g_free(source_filename);
+        g_free(target_filename);
+    }
+    g_dir_close(dir_path);
+}
 /*------------------------------------------------------------------------------*/
 
-int
+static gint
 untar_archive (gchar *filename)
 {
 	struct archive_entry *entry;
@@ -102,7 +125,7 @@ untar_archive (gchar *filename)
 	    (archive_read_open_filename (archive, filename, 8192) != ARCHIVE_OK))
 	{
 		archive_read_free (archive);
-		g_printf ("%s\n", archive_error_string (archive));
+        fprintf(stderr, "%s\n", archive_error_string(archive));
 		return archive_errno (archive);
 	}
 
@@ -114,128 +137,85 @@ untar_archive (gchar *filename)
 	return ARCHIVE_OK;
 }
 
+
 /*------------------------------------------------------------------------------*/
+static void
+create_backup_file(const gchar *filename, const gchar *password, GUI *appGUI) {
+    gchar *backup_filename;
+    GRG_CTX context;
+    GRG_KEY keyholder;
+    gchar *contents;
+    gchar *notes;
+    gsize len;
+    struct archive *archive;
 
-void
-add_all_files_to_list (gchar *directory, gboolean subdir, GUI *appGUI) {
+    /* create backup file */
+    backup_filename = g_strdup(prefs_get_cache_filename("backup.dat"));
+    archive = create_archive(backup_filename);
+    if (!archive) {
+        utl_gui_create_dialog(GTK_MESSAGE_ERROR, _("Cannot create backup!"), GTK_WINDOW(appGUI->main_window));
+        g_unlink(backup_filename);
+        g_free(backup_filename);
+        return;
+    }
 
-GDir *dir_path = NULL;
-const gchar *item_name = NULL;
-gchar *full_filename = NULL, *fitem = NULL, *sdir = NULL;
-gchar separator[2] = { G_DIR_SEPARATOR, '\0' };
+    /* add files to archive */
+    add_to_archive(prefs_get_config_dir(appGUI), CONFIG_FILENAME, "", archive);
+    add_to_archive(prefs_get_data_dir(appGUI), "xml", "", archive);
+    notes = g_build_filename(prefs_get_data_dir(appGUI), "notes", NULL);
+    add_to_archive(notes, "osm", "notes", archive);
+    g_free(notes);
 
-	dir_path = g_dir_open (directory, 0, NULL);
-	g_return_if_fail (dir_path != NULL);
+    /* done writing backup */
+    close_archive(archive);
 
-    while ((item_name = g_dir_read_name (dir_path)) != NULL) {
+    if (g_file_get_contents(backup_filename, &contents, &len, NULL) == FALSE) {
+        utl_gui_create_dialog(GTK_MESSAGE_ERROR, _("Cannot create backup!"), GTK_WINDOW(appGUI->main_window));
+        g_unlink(backup_filename);
+        g_free(backup_filename);
+        return;
+    }
 
-		full_filename = g_strconcat (directory, separator, item_name, NULL);
+    context = grg_context_initialize_defaults((unsigned char*) "BCK");
+    keyholder = grg_key_gen((unsigned char*) password, -1);
 
-		if (g_utf8_collate (item_name, BACKUP_TEMPLATE) == 0) {     /* don't include backup file! */
-			g_free (full_filename);
-			continue;
-		}
+    if (keyholder == NULL || context == NULL) {
+        utl_gui_create_dialog(GTK_MESSAGE_ERROR, _("Cannot create backup!"), GTK_WINDOW(appGUI->main_window));
+        g_unlink(backup_filename);
+        g_free(backup_filename);
+        return;
+    }
 
-		if (g_file_test (full_filename, G_FILE_TEST_IS_SYMLINK)) {  /* ignore symlinks */
-			g_free (full_filename);
-			continue;
-		}
+    grg_ctx_set_crypt_algo(context, get_enc_algorithm_value());
+    grg_ctx_set_hash_algo(context, get_enc_hashing_value());
+    grg_ctx_set_comp_algo(context, get_comp_algorithm_value());
+    grg_ctx_set_comp_ratio(context, get_comp_ratio_value());
+    grg_encrypt_file(context, keyholder, (unsigned char*) filename, (guchar *) contents, len);
+    grg_free(context, contents, len);
+    grg_key_free(context, keyholder);
+    grg_context_free(context);
 
-		if (g_file_test (full_filename, G_FILE_TEST_IS_DIR)) {
-			add_all_files_to_list (full_filename, TRUE, appGUI);
-			g_free (full_filename);
-			continue;
-		}
-
-		if (subdir) {
-			sdir = g_path_get_basename (directory);
-			fitem = g_strconcat (sdir, separator, item_name, NULL);
-			g_free (sdir);
-		} else {
-			fitem = g_strdup (item_name);
-		}
-		g_free (full_filename);
-
-        appGUI->file_list = g_slist_append (appGUI->file_list, fitem);
-	}
-
-	g_dir_close (dir_path);
+    /* clean up*/
+    g_unlink(backup_filename);
+    g_free(backup_filename);
 }
 
-/*------------------------------------------------------------------------------*/
-
-void
-add_files_to_list (gchar *directory, gchar *extension, GUI *appGUI) {
-
-GDir *dir_path = NULL;
-const gchar *item_name = NULL;
-gchar *full_filename = NULL, *fitem = NULL;
-gchar separator[2] = { G_DIR_SEPARATOR, '\0' };
-
-	dir_path = g_dir_open (directory, 0, NULL);
-	g_return_if_fail (dir_path != NULL);
-
-    while ((item_name = g_dir_read_name (dir_path)) != NULL) {
-
-		full_filename = g_strconcat (directory, separator, item_name, NULL);
-
-		if (!g_file_test (full_filename, G_FILE_TEST_IS_REGULAR)) {
-			g_free (full_filename);
-			continue;
-		}
-
-		if (!g_str_has_suffix (item_name, extension)) {
-			g_free (full_filename);
-			continue;
-		}
-
-		if (g_str_has_suffix (item_name, "osm")) {
-			g_free (full_filename);
-			full_filename = g_strconcat ("notes", separator, item_name, NULL);
-			fitem = g_strdup (full_filename);
-		} else {
-			fitem = g_strdup (item_name);
-		}
-
-		g_free (full_filename);
-
-        appGUI->file_list = g_slist_append (appGUI->file_list, fitem);
-	}
-
-	g_dir_close (dir_path);
-}
-
-/*------------------------------------------------------------------------------*/
-
 void
 backup_create (GUI *appGUI) {
 
-gchar *home_dirname = NULL;
-gint ret, p1len, p2len, tErr;
-GRG_CTX context;
-GRG_KEY keyholder;
-gchar *filename, *password, *bpass1, *bpass2, *tmp_filename;
+gint ret, p1len, p2len;
+gchar *filename, *password, *bpass1, *bpass2;
 gchar tmpbuf[BUFFER_SIZE];
-gchar *contents;
-gsize len;
 GtkWidget *dialog, *passwd_dialog;
-GtkWidget *vbox1, *alignment, *frame, *label;
+GtkWidget *passwd_content, *vbox1, *frame, *label;
 GtkWidget *bck_p1_entry, *bck_p2_entry;
 
 	/* select filename and password */
 
-    dialog = gtk_file_chooser_dialog_new (_("Save backup"),
-                                          GTK_WINDOW(appGUI->main_window),
-                                          GTK_FILE_CHOOSER_ACTION_SAVE,
-                                          GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                          GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
-                                          NULL);
-
-    gtk_window_set_position (GTK_WINDOW(dialog), GTK_WIN_POS_CENTER_ON_PARENT);
-    gtk_file_chooser_set_select_multiple (GTK_FILE_CHOOSER(dialog), FALSE);
-    gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER(dialog), 
-									   utl_add_timestamp_to_filename ("osmobackup", "bck"));
-	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER(dialog), TRUE);
+    dialog = utl_gui_create_save_file_dialog (_("Save backup"),
+                                          GTK_WINDOW(appGUI->main_window));
+    gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER(dialog),
+            utl_add_timestamp_to_filename("osmobackup", "bck"));
 
 	ret = gtk_dialog_run(GTK_DIALOG(dialog));
     if (ret == GTK_RESPONSE_CANCEL || ret == GTK_RESPONSE_DELETE_EVENT) {
@@ -255,36 +235,35 @@ GtkWidget *bck_p1_entry, *bck_p2_entry;
     passwd_dialog = gtk_dialog_new_with_buttons (_("Password protection"), 
 												 GTK_WINDOW(appGUI->main_window),
                                                  GTK_DIALOG_MODAL,
-                                                 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                                 GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, 
+                                                 _("_Cancel"), GTK_RESPONSE_CANCEL,
+                                                 _("_OK"), GTK_RESPONSE_ACCEPT,
 												 NULL);
 
 	gtk_window_set_position (GTK_WINDOW(passwd_dialog), GTK_WIN_POS_CENTER_ON_PARENT);
 	gtk_window_set_default_size (GTK_WINDOW(passwd_dialog), 400, -1);
     gtk_dialog_set_default_response (GTK_DIALOG(passwd_dialog), GTK_RESPONSE_ACCEPT);
 
-	vbox1 = gtk_vbox_new (FALSE, 0);
+	vbox1 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
     gtk_widget_show (vbox1);
-    gtk_box_pack_start (GTK_BOX (GTK_DIALOG(passwd_dialog)->vbox), vbox1, TRUE, TRUE, 16);
+    passwd_content = gtk_dialog_get_content_area(GTK_DIALOG(passwd_dialog));
+    gtk_container_add(GTK_CONTAINER(passwd_content), vbox1);
 
 	frame = gtk_frame_new (NULL);
     gtk_widget_show (frame);
     gtk_box_pack_start (GTK_BOX (vbox1), frame, FALSE, FALSE, 0);
     gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
-
-    alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
-    gtk_widget_show (alignment);
-    gtk_container_add (GTK_CONTAINER (frame), alignment);
-    gtk_container_set_border_width (GTK_CONTAINER (alignment), 4);
-    gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
 	
     bck_p1_entry = gtk_entry_new ();
     gtk_widget_show (bck_p1_entry);
-    gtk_container_add (GTK_CONTAINER (alignment), bck_p1_entry);
+    gtk_container_add (GTK_CONTAINER (frame), bck_p1_entry);
+    gtk_widget_set_margin_left(bck_p1_entry, 16);
+    gtk_widget_set_margin_right(bck_p1_entry, 4);
+    gtk_widget_set_margin_top(bck_p1_entry, 4);
+    gtk_widget_set_margin_bottom(bck_p1_entry, 4);
     gtk_entry_set_invisible_char (GTK_ENTRY (bck_p1_entry), 8226);
     gtk_entry_set_visibility (GTK_ENTRY (bck_p1_entry), FALSE);
 
-    sprintf (tmpbuf, "<b>%s:</b>", _("Enter password"));
+    g_snprintf(tmpbuf, BUFFER_SIZE, "<b>%s:</b>", _("Enter password"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
     gtk_frame_set_label_widget (GTK_FRAME (frame), label);
@@ -295,19 +274,17 @@ GtkWidget *bck_p1_entry, *bck_p2_entry;
     gtk_box_pack_start (GTK_BOX (vbox1), frame, FALSE, FALSE, 0);
     gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
 
-    alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
-    gtk_widget_show (alignment);
-    gtk_container_add (GTK_CONTAINER (frame), alignment);
-    gtk_container_set_border_width (GTK_CONTAINER (alignment), 4);
-    gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
-
     bck_p2_entry = gtk_entry_new ();
     gtk_widget_show (bck_p2_entry);
-    gtk_container_add (GTK_CONTAINER (alignment), bck_p2_entry);
+    gtk_container_add (GTK_CONTAINER (frame), bck_p2_entry);
+    gtk_widget_set_margin_left(bck_p2_entry, 16);
+    gtk_widget_set_margin_right(bck_p2_entry, 4);
+    gtk_widget_set_margin_top(bck_p2_entry, 4);
+    gtk_widget_set_margin_bottom(bck_p2_entry, 4);
     gtk_entry_set_invisible_char (GTK_ENTRY (bck_p2_entry), 8226);
     gtk_entry_set_visibility (GTK_ENTRY (bck_p2_entry), FALSE);
 
-    sprintf (tmpbuf, "<b>%s:</b>", _("Re-enter password"));
+    g_snprintf(tmpbuf, BUFFER_SIZE, "<b>%s:</b>", _("Re-enter password"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
     gtk_frame_set_label_widget (GTK_FRAME (frame), label);
@@ -358,70 +335,11 @@ GtkWidget *bck_p1_entry, *bck_p2_entry;
 	password = g_strdup(gtk_entry_get_text(GTK_ENTRY(bck_p1_entry)));
 	gtk_widget_destroy(passwd_dialog);
 
-	/* generate file list */
 
-	appGUI->file_list = NULL;
-
-	home_dirname = g_strdup (prefs_get_config_dir(appGUI));
-	add_all_files_to_list (home_dirname, FALSE, appGUI);
-	g_free (home_dirname);
-
-	/* create backup file */
-
-	tmp_filename = g_strdup (prefs_get_config_filename ("backup.dat", appGUI));
-
-	home_dirname = g_get_current_dir();
-	g_chdir (prefs_get_config_dir(appGUI));     /* change directory to cfg home */
-	g_unlink (tmp_filename);
-
-	tErr = tar_archive (tmp_filename, appGUI);
-
-	g_chdir (home_dirname);
-	g_free (home_dirname);
-
-	if (tErr != ARCHIVE_OK) {
-		utl_gui_create_dialog (GTK_MESSAGE_ERROR, _("Cannot create backup!"), GTK_WINDOW(appGUI->main_window));
-		return;
-	}
-
-	if (g_file_get_contents (tmp_filename, &contents, &len, NULL) == FALSE) {
-		utl_gui_create_dialog (GTK_MESSAGE_ERROR, _("Cannot create backup!"), GTK_WINDOW(appGUI->main_window));
-		return;
-	}
-
-	context = grg_context_initialize_defaults ((unsigned char*) "BCK");
-	keyholder = grg_key_gen ((unsigned char*) password, -1);
-
-	if (keyholder == NULL || context == NULL) {
-		utl_gui_create_dialog (GTK_MESSAGE_ERROR, _("Cannot create backup!"), GTK_WINDOW(appGUI->main_window));
-		return;
-	}
-
-	grg_ctx_set_crypt_algo (context, get_enc_algorithm_value());
-	grg_ctx_set_hash_algo (context, get_enc_hashing_value());
-	grg_ctx_set_comp_algo (context, get_comp_algorithm_value());
-	grg_ctx_set_comp_ratio (context, get_comp_ratio_value());
-    grg_encrypt_file (context, keyholder, (unsigned char*) filename, (guchar *) contents, len);
-    grg_free (context, contents, len);
-	grg_key_free (context, keyholder);
-	grg_context_free (context);
-
-	g_unlink (tmp_filename);
-
-	/* free strings */
-
-	g_free (tmp_filename);
-
-	g_free(filename);
+        create_backup_file(filename, password, appGUI);
+        
+        g_free(filename);
 	g_free(password);
-
-	/* free list */
-
-	if (appGUI->file_list != NULL) {
-		g_slist_foreach (appGUI->file_list, (GFunc) g_free, NULL);
-		g_slist_free (appGUI->file_list);
-		appGUI->file_list = NULL;
-	}
 	
 	utl_gui_create_dialog (GTK_MESSAGE_INFO, _("Backup file saved successfully!"), GTK_WINDOW(appGUI->main_window));
 }
@@ -441,18 +359,10 @@ long arch_len;
 gchar *contents, *password;
 gchar tmpbuf[BUFFER_SIZE];
 GtkWidget *dialog, *passwd_dialog, *pass_entry;
-GtkWidget *vbox1, *alignment, *frame, *label;
+GtkWidget *passwd_content, *vbox1, *frame, *label;
 
-    dialog = gtk_file_chooser_dialog_new (_("Open backup file"),
-                                          GTK_WINDOW(appGUI->main_window),
-                                          GTK_FILE_CHOOSER_ACTION_OPEN,
-                                          GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                          GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
-                                          NULL);
-
-    gtk_window_set_position (GTK_WINDOW(dialog), GTK_WIN_POS_CENTER_ON_PARENT);
-    gtk_file_chooser_set_select_multiple (GTK_FILE_CHOOSER(dialog), FALSE);
-	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER(dialog), TRUE);
+    dialog = utl_gui_create_open_file_dialog (_("Open backup file"),
+                                          GTK_WINDOW(appGUI->main_window));
 
 	filter = gtk_file_filter_new();
     gtk_file_filter_add_pattern(filter, "*.[bB][cC][kK]");
@@ -490,36 +400,35 @@ GtkWidget *vbox1, *alignment, *frame, *label;
     passwd_dialog = gtk_dialog_new_with_buttons (_("Password protection"), 
 												 GTK_WINDOW(appGUI->main_window),
                                                  GTK_DIALOG_MODAL,
-                                                 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                                 GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, 
+                                                 _("_Cancel"), GTK_RESPONSE_CANCEL,
+                                                 _("_OK"), GTK_RESPONSE_ACCEPT,
 												 NULL);
 
 	gtk_window_set_position (GTK_WINDOW(passwd_dialog), GTK_WIN_POS_CENTER_ON_PARENT);
 	gtk_window_set_default_size (GTK_WINDOW(passwd_dialog), 400, -1);
     gtk_dialog_set_default_response (GTK_DIALOG(passwd_dialog), GTK_RESPONSE_ACCEPT);
 
-	vbox1 = gtk_vbox_new (FALSE, 0);
+	vbox1 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
     gtk_widget_show (vbox1);
-    gtk_box_pack_start (GTK_BOX (GTK_DIALOG(passwd_dialog)->vbox), vbox1, TRUE, TRUE, 8);
+    passwd_content = gtk_dialog_get_content_area(GTK_DIALOG(passwd_dialog));
+    gtk_container_add(GTK_CONTAINER(passwd_content), vbox1);
 
 	frame = gtk_frame_new (NULL);
     gtk_widget_show (frame);
     gtk_box_pack_start (GTK_BOX (vbox1), frame, FALSE, FALSE, 0);
     gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
-
-    alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
-    gtk_widget_show (alignment);
-    gtk_container_add (GTK_CONTAINER (frame), alignment);
-    gtk_container_set_border_width (GTK_CONTAINER (alignment), 4);
-    gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
 	
     pass_entry = gtk_entry_new ();
     gtk_widget_show (pass_entry);
-    gtk_container_add (GTK_CONTAINER (alignment), pass_entry);
+    gtk_container_add (GTK_CONTAINER (frame), pass_entry);
+    gtk_widget_set_margin_left(pass_entry, 16);
+    gtk_widget_set_margin_right(pass_entry, 4);
+    gtk_widget_set_margin_top(pass_entry, 4);
+    gtk_widget_set_margin_bottom(pass_entry, 4);
     gtk_entry_set_invisible_char (GTK_ENTRY (pass_entry), 8226);
     gtk_entry_set_visibility (GTK_ENTRY (pass_entry), FALSE);
 
-    sprintf (tmpbuf, "<b>%s:</b>", _("Enter password"));
+    g_snprintf(tmpbuf, BUFFER_SIZE, "<b>%s:</b>", _("Enter password"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
     gtk_frame_set_label_widget (GTK_FRAME (frame), label);
@@ -553,7 +462,7 @@ GtkWidget *vbox1, *alignment, *frame, *label;
 
 	/* extracting encrypted data */
 
-	tmp_filename = g_strdup (prefs_get_config_filename (BACKUP_TEMPLATE, appGUI));
+	tmp_filename = g_strdup (prefs_get_cache_filename (BACKUP_TEMPLATE));
 	g_unlink (tmp_filename);
 
 	context = grg_context_initialize_defaults ((unsigned char*) "BCK");
@@ -583,7 +492,7 @@ GtkWidget *vbox1, *alignment, *frame, *label;
 		
 	tErr = -1;
 
-    sprintf (tmpbuf, "%s\n\n%s", 
+    g_snprintf(tmpbuf, BUFFER_SIZE, "%s\n\n%s", 
 			 _("All your data will be replaced with backup file content."), _("Are you sure?"));
 
 	ret = utl_gui_create_dialog (GTK_MESSAGE_QUESTION, tmpbuf, GTK_WINDOW(appGUI->main_window));
@@ -605,7 +514,7 @@ GtkWidget *vbox1, *alignment, *frame, *label;
 	g_free(tmp_filename);
 
 	if (!tErr) {
-        sprintf (tmpbuf, "%s", _("Osmo has to be restarted now..."));
+        g_snprintf(tmpbuf, BUFFER_SIZE, "%s", _("Osmo has to be restarted now..."));
 		utl_gui_create_dialog (GTK_MESSAGE_INFO, tmpbuf, GTK_WINDOW(appGUI->main_window));
 		gui_quit_osmo (appGUI);
 	}
@@ -613,65 +522,58 @@ GtkWidget *vbox1, *alignment, *frame, *label;
 }
 
 /*------------------------------------------------------------------------------*/
+static void
+delete_dir(gchar *dir) {
+    GDir *dir_fd = g_dir_open(dir, 0, NULL);
+    if (dir_fd) {
+        const gchar *child = g_dir_read_name(dir_fd);
+        for (; child; child = g_dir_read_name(dir_fd)) {
+            gchar *child_fullname = g_build_filename(dir, child, NULL);
+            if (g_file_test(child_fullname, G_FILE_TEST_IS_DIR)) {
+                delete_dir(child_fullname);
+            } else {
+                g_remove(child_fullname);
+            }
+            g_free(child_fullname);
+        }
+        g_remove(dir);
+    }
+}
 
 void
 backup_restore_run (GUI *appGUI) {
 
-gint i;
-gchar *tmp_filename, *home_dirname;
-const gchar *item_name = NULL;
-gchar *fitem = NULL, separator[2] = { G_DIR_SEPARATOR, '\0' };
+gchar *tmp_filename, *tmp_dirname, *home_dirname;
 
 	/* is backup file available? */
-
-	tmp_filename = g_strdup (prefs_get_config_filename (BACKUP_TEMPLATE, appGUI));
-
+	tmp_filename = g_strdup (prefs_get_cache_filename (BACKUP_TEMPLATE));
 	if (g_file_test (tmp_filename, G_FILE_TEST_IS_REGULAR) == FALSE) {
 		g_free (tmp_filename);
 		return;
 	}
 
-	/* removing old files */
-
-	appGUI->file_list = NULL;
-
-	home_dirname = g_strdup (prefs_get_config_dir(appGUI));
-	add_files_to_list (home_dirname, ".xml", appGUI);
-
-	item_name = g_strconcat (home_dirname, separator, "notes", NULL);
-	g_free (home_dirname);
-	home_dirname = g_strdup (item_name);
-	
-	add_files_to_list (home_dirname, ".osm", appGUI);
-
-	g_free (home_dirname);
-
-	/* change directory to cfg home */
-
+	/* prepare and change to a temporary directory */
 	home_dirname = g_get_current_dir();
-	g_chdir (prefs_get_config_dir(appGUI));
-
-	i = 0;
-
-	while ((fitem = g_slist_nth_data (appGUI->file_list, i)) != NULL) {
-		g_unlink (fitem);
-		i++;
-	}
+        tmp_dirname = g_dir_make_tmp(NULL, NULL);
+        if(!tmp_dirname) {
+            g_free (tmp_filename);
+            g_return_if_fail(tmp_dirname != NULL);
+        }
+	g_chdir (tmp_dirname);
 
 	/* untar files */
-
 	untar_archive (tmp_filename);
+        
+        /* copy to the correct directories */
+        prefs_restore(tmp_dirname, appGUI);
+        delete_dir(tmp_dirname);
 
 	/* clean up */
 
 	g_chdir (home_dirname);
 	g_free (home_dirname);
 
-	if (appGUI->file_list != NULL) {
-		g_slist_foreach (appGUI->file_list, (GFunc) g_free, NULL);
-		g_slist_free (appGUI->file_list);
-		appGUI->file_list = NULL;
-	}
+	g_free (tmp_dirname);
 
 	g_unlink (tmp_filename);
 	g_free (tmp_filename);
