@@ -30,7 +30,6 @@ void        gui_set_calendar_defaults               (GtkWidget *calendar);
 void        cal_jump_to_date                        (GDate *cdate, GUI *appGUI);
 void        calendar_set_today                      (GUI *appGUI);
 void        calendar_update_date                    (guint day, guint month, guint year, GUI *appGUI);
-void        calendar_update_note                    (guint uday, guint umonth, guint uyear, gchar *color, GUI *appGUI);
 void        calendar_clear_text_cb                  (GtkWidget *widget, gpointer data);
 void        enable_disable_note_buttons             (GUI *appGUI);
 gchar *     get_marker_symbol                       (gint idx);
@@ -40,12 +39,11 @@ void        calendar_create_popup_menu              (GtkWidget *menu, GUI *appGU
 void        cal_set_day_info                        (GUI *appGUI);
 void        mark_events                             (GtkWidget *calendar, guint month, guint year, GUI *appGUI);
 void        cal_refresh_marks                       (GUI *appGUI);
+void        cal_refresh_notes                       (GUI *appGUI);
 void        update_clock                            (GUI *appGUI);
 void        update_aux_calendars                    (GUI *appGUI);
 void        calendar_mark_events                    (GtkWidget *calendar, guint32 julian_day, guint i, GUI *appGUI);
 
-void        calendar_store_note                     (GUI *appGUI);
-
 void        calendar_btn_prev_day                   (GUI *appGUI);
 void        calendar_btn_next_day                   (GUI *appGUI);
 void        calendar_btn_prev_week                  (GUI *appGUI);
