@@ -70,7 +70,6 @@ GDate *date;
 	cal_jump_to_date (date, msg->appGUI);
 	g_date_free (date);
 
-	update_aux_calendars (msg->appGUI);
 	fullyear_window_close_cb (GTK_WIDGET (widget), NULL, msg->appGUI);
 }
 
@@ -302,7 +301,6 @@ calendar_dbclick_cb (GtkWidget *widget, gpointer user_data)
 
 	gui_calendar_get_gdate (GUI_CALENDAR (widget), date);
 	cal_jump_to_date (date, appGUI);
-	update_aux_calendars (appGUI);
 	g_date_free (date);
 
 	fullyear_window_close_cb (GTK_WIDGET (widget), NULL, appGUI);
