@@ -285,16 +285,14 @@ gint n = 0;
 void
 ics_check_if_valid (GUI *appGUI) {
 
-gint i;
 gchar *ical_filename, *ical_name;
 GtkTreeIter iter;
 GdkPixbuf *image;
 const gchar *icon_name;
-gboolean status, disable;
+gboolean status, disable, has_next;
 
-    i = 0;
-
-    while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->opt->calendar_ical_files_store), &iter, NULL, i++)) {
+    has_next = gtk_tree_model_get_iter_first (GTK_TREE_MODEL(appGUI->opt->calendar_ical_files_store), &iter);
+    while (has_next) {
 
         gtk_tree_model_get(GTK_TREE_MODEL(appGUI->opt->calendar_ical_files_store), &iter, 
                            ICAL_COLUMN_NAME, &ical_name, ICAL_COLUMN_FILENAME, &ical_filename, 
@@ -317,6 +315,7 @@ gboolean status, disable;
         g_object_unref (image);
         g_free (ical_name);
         g_free (ical_filename);
+        has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL(appGUI->opt->calendar_ical_files_store), &iter);
     }
 
 }
@@ -333,18 +332,17 @@ ics_check_event (guint32 julian, GUI *appGUI)
     gboolean valid_ics, year_flag, mark_flag, disabled;
     gboolean found;
     gchar *ical_filename;
-    gint i;
 
     if (!g_date_valid_julian (julian)) return FALSE;
 
     found = FALSE;
 
     for (node = appGUI->cal->ics_files_list; node != NULL; node = node->next) {
-
+        gboolean has_next;
         entry = node->data;
 
-        i = 0;
-        while (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (appGUI->opt->calendar_ical_files_store), &iter, NULL, i++)) {
+        has_next = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (appGUI->opt->calendar_ical_files_store), &iter);
+        while (has_next) {
 
             gtk_tree_model_get (GTK_TREE_MODEL (appGUI->opt->calendar_ical_files_store), &iter,
                                 ICAL_COLUMN_FILENAME, &ical_filename,
@@ -359,6 +357,7 @@ ics_check_event (guint32 julian, GUI *appGUI)
             }
 
             g_free (ical_filename);
+            has_next = gtk_tree_model_iter_next(GTK_TREE_MODEL (appGUI->opt->calendar_ical_files_store), &iter);
         }
 
         if (entry->entries_list != NULL && valid_ics == TRUE && disabled == FALSE && mark_flag == TRUE && year_flag == TRUE) {
@@ -397,16 +396,17 @@ calendar_display_ics (GDate *date, gchar **html, GUI *appGUI)
     struct ics_entry *item, *sitem;
     gboolean valid_ics, desc_flag, year_flag, mark_flag, title_flag, disabled;
     gchar *ical_name, *ical_filename;
-    gint i, day, month, year;
+    gint day, month, year;
     gint jd, jm, jy;
 
     utl_date_get_dmy (date, &day, &month, &year);
 
     for (node = appGUI->cal->ics_files_list; node != NULL; node = node->next) {
+        gboolean has_next;
         entry = node->data;
-        i = 0;
 
-        while (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (appGUI->opt->calendar_ical_files_store), &iter, NULL, i++)) {
+        has_next = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (appGUI->opt->calendar_ical_files_store), &iter);
+        while (has_next) {
 
             gtk_tree_model_get (GTK_TREE_MODEL (appGUI->opt->calendar_ical_files_store), &iter,
                                 ICAL_COLUMN_NAME, &ical_name,
@@ -424,6 +424,7 @@ calendar_display_ics (GDate *date, gchar **html, GUI *appGUI)
 
             g_free (ical_name);
             g_free (ical_filename);
+            has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (appGUI->opt->calendar_ical_files_store), &iter);
         }
 
         title_flag = FALSE;
@@ -482,16 +483,14 @@ ics_calendar_init (GUI *appGUI) {
 struct ics_file *ics_file_entry;
 gchar *ical_name, *ical_filename;
 GtkTreeIter iter;
-gint i;
-gboolean flag, desc_flag, disabled;
+gboolean flag, desc_flag, disabled, has_next;
 
     ics_initialize_timezone ();
 
     appGUI->cal->ics_files_list = NULL;
 
-    i = 0;
-
-    while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->opt->calendar_ical_files_store), &iter, NULL, i++)) {
+    has_next = gtk_tree_model_get_iter_first (GTK_TREE_MODEL(appGUI->opt->calendar_ical_files_store), &iter);
+    while (has_next) {
 
         gtk_tree_model_get(GTK_TREE_MODEL(appGUI->opt->calendar_ical_files_store), &iter, 
                            ICAL_COLUMN_NAME, &ical_name, ICAL_COLUMN_FILENAME, &ical_filename, 
@@ -515,6 +514,7 @@ gboolean flag, desc_flag, disabled;
 
         g_free (ical_name);
         g_free (ical_filename);
+        has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL(appGUI->opt->calendar_ical_files_store), &iter);
     }
 
 }
@@ -662,9 +662,8 @@ xmlDocPtr doc;
 xmlNodePtr main_node, entry_node;
 xmlAttrPtr attr;
 GtkTreeIter iter;
-gint i;
 gchar *ical_name, *ical_filename;
-gboolean desc_flag, mark_flag, year_flag, disabled;
+gboolean desc_flag, mark_flag, year_flag, disabled, has_next;
 gchar tmpbuf[BUFFER_SIZE];
 
     doc = xmlNewDoc((const xmlChar *) "1.0");
@@ -673,10 +672,8 @@ gchar tmpbuf[BUFFER_SIZE];
     main_node = xmlNewNode(NULL, (const xmlChar *) ICAL_NAME);
     xmlDocSetRootElement(doc, main_node);
 
-    i = 0;
-
-    while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->opt->calendar_ical_files_store), &iter, NULL, i++)) {
-
+    has_next = gtk_tree_model_get_iter_first (GTK_TREE_MODEL(appGUI->opt->calendar_ical_files_store), &iter);
+    while (has_next) {
         gtk_tree_model_get (GTK_TREE_MODEL(appGUI->opt->calendar_ical_files_store), &iter, 
                             ICAL_COLUMN_NAME, &ical_name, ICAL_COLUMN_FILENAME, &ical_filename, 
                             ICAL_COLUMN_ENABLE_DESC, &desc_flag, 
@@ -697,6 +694,7 @@ gchar tmpbuf[BUFFER_SIZE];
         xmlNewChild (entry_node, NULL, (const xmlChar *) "mark", (xmlChar *) tmpbuf);
         g_snprintf(tmpbuf, BUFFER_SIZE, "%d", year_flag);
         xmlNewChild (entry_node, NULL, (const xmlChar *) "use_year", (xmlChar *) tmpbuf);
+        has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL(appGUI->opt->calendar_ical_files_store), &iter);
     }
 
     utl_xml_write_doc (prefs_get_data_filename(ICAL_ENTRIES_FILENAME, appGUI), doc);
@@ -763,7 +761,7 @@ ical_events_list_create (gint calendar, GUI *appGUI)
     struct ics_entry *item;
     GtkTreeIter iter;
     GSList *node;
-    gboolean year_flag = FALSE, valid_flag, disabled;
+    gboolean year_flag = FALSE, valid_flag, disabled, has_next;
     guint32 julian;
     gint j, n, cday, cmonth, cyear;
     gint jd, jm, jy;
@@ -773,14 +771,17 @@ ical_events_list_create (gint calendar, GUI *appGUI)
     utl_date_get_current_dmy (&cday, &cmonth, &cyear);
 
     /* get year flag */
-    j = n = 0;
-    while (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (appGUI->opt->calendar_ical_files_store), &iter, NULL, j++)) {
-        gtk_tree_model_get (GTK_TREE_MODEL (appGUI->opt->calendar_ical_files_store), &iter,
-                            ICAL_COLUMN_FULL_DATE, &year_flag, ICAL_COLUMN_VALID_FLAG, &valid_flag, 
-                            ICAL_COLUMN_DISABLED, &disabled, -1);
-        if (valid_flag == FALSE || disabled == TRUE) continue;
-        if (n == calendar) break;
-        n++;
+    n = 0;
+    has_next = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(appGUI->opt->calendar_ical_files_store), &iter);
+    while (has_next) {
+        gtk_tree_model_get(GTK_TREE_MODEL(appGUI->opt->calendar_ical_files_store), &iter,
+                ICAL_COLUMN_FULL_DATE, &year_flag, ICAL_COLUMN_VALID_FLAG, &valid_flag,
+                ICAL_COLUMN_DISABLED, &disabled, -1);
+        if (valid_flag == TRUE && disabled == FALSE) {
+            if (n == calendar) break;
+            n++;
+        }
+        has_next = gtk_tree_model_iter_next(GTK_TREE_MODEL(appGUI->opt->calendar_ical_files_store), &iter);
     }
 
     entry = g_slist_nth_data (appGUI->cal->ics_files_list, calendar);
@@ -915,14 +916,16 @@ GtkWidget           *table;
 GtkWidget           *label;
 gchar tmpbuf[BUFFER_SIZE];
 gchar *ical_name;
-gboolean valid, disabled;
-gint i, k;
+gboolean valid, disabled, has_next;
+gint k;
 
-    i = k = 0;
-    while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->opt->calendar_ical_files_store), &iter, NULL, i++)) {
+    k = 0;
+    has_next = gtk_tree_model_get_iter_first (GTK_TREE_MODEL(appGUI->opt->calendar_ical_files_store), &iter);
+    while (has_next) {
         gtk_tree_model_get(GTK_TREE_MODEL(appGUI->opt->calendar_ical_files_store), &iter, 
                            ICAL_COLUMN_VALID_FLAG, &valid, ICAL_COLUMN_DISABLED, &disabled, -1);
         if (valid == TRUE && disabled == FALSE) k++;
+        has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL(appGUI->opt->calendar_ical_files_store), &iter);
     }
 
     if (k < 1) {
@@ -973,9 +976,8 @@ gint i, k;
     g_signal_connect(appGUI->cal->ical_combobox, "changed", 
                      G_CALLBACK(calendar_selected_cb), appGUI);
 
-    k = 0;
-
-    while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->opt->calendar_ical_files_store), &iter, NULL, k++)) {
+    has_next = gtk_tree_model_get_iter_first (GTK_TREE_MODEL(appGUI->opt->calendar_ical_files_store), &iter);
+    while (has_next) {
 
         gtk_tree_model_get(GTK_TREE_MODEL(appGUI->opt->calendar_ical_files_store), &iter, 
                            ICAL_COLUMN_NAME, &ical_name, ICAL_COLUMN_VALID_FLAG, &valid, 
@@ -985,6 +987,7 @@ gint i, k;
             gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (appGUI->cal->ical_combobox), NULL, ical_name);
         }
         g_free (ical_name);
+        has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL(appGUI->opt->calendar_ical_files_store), &iter);
     }
 
     appGUI->cal->n_items_label = gtk_label_new ("");
@@ -1212,14 +1215,7 @@ calendar_begin_end_day_selected_cb (GuiCalendar *calendar, gpointer user_data)
 
 gint
 get_export_items (GUI *appGUI) {
-
-GtkTreeIter iter;
-gint i;
-
-    i = 0;
-    while (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (appGUI->cal->export_events_list_store), &iter, NULL, i++));
-
-    return i-1;
+    return gtk_tree_model_iter_n_children (GTK_TREE_MODEL (appGUI->cal->export_events_list_store), NULL);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -1376,7 +1372,8 @@ ical_export_cb (GtkButton *button, gpointer user_data) {
 
 GtkTreeIter iter;
 gchar *filename;
-gint i;
+gint count = 0;
+gboolean has_next;
 guint32 julian_day;
 gint day, month, year;
 gchar *summary, *description;
@@ -1409,8 +1406,6 @@ gchar tmpbuf[BUFFER_SIZE];
         return;
     }
 
-    i = 0;
-
     calendar = icalcomponent_new (ICAL_VCALENDAR_COMPONENT);
 
     prop = icalproperty_new_prodid ("//Clay//NONSGML Osmo PIM//EN");
@@ -1418,7 +1413,9 @@ gchar tmpbuf[BUFFER_SIZE];
     prop = icalproperty_new_version (VERSION);
     icalcomponent_add_property (calendar, prop);
 
-    while (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (appGUI->cal->export_events_list_store), &iter, NULL, i++)) {
+    has_next = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (appGUI->cal->export_events_list_store), &iter);
+    while (has_next) {
+        count++;
 
         gtk_tree_model_get (GTK_TREE_MODEL (appGUI->cal->export_events_list_store), &iter,
                             IE_COLUMN_DATE_JULIAN, &julian_day, 
@@ -1432,7 +1429,7 @@ gchar tmpbuf[BUFFER_SIZE];
         atime.month = month;
         atime.year = year;
         atime.is_date = 1;
-        g_snprintf (tmpbuf, BUFFER_SIZE, "id%d%d%d%d@clayo.org", year, month, day, i);
+        g_snprintf (tmpbuf, BUFFER_SIZE, "id%d%d%d%d@clayo.org", year, month, day, count);
         prop = icalproperty_new_uid (tmpbuf);
         icalcomponent_add_property (event, prop);
         icalproperty_free (prop);
@@ -1454,6 +1451,7 @@ gchar tmpbuf[BUFFER_SIZE];
         icalcomponent_free (event);
         g_free (summary);
         g_free (description);
+        has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (appGUI->cal->export_events_list_store), &iter);
     }
 
     icalset_add_component (ics_file, calendar);
@@ -1462,9 +1460,9 @@ gchar tmpbuf[BUFFER_SIZE];
     icalcomponent_free (calendar);
     g_free (filename);
 
-    if (i >= 2) {
-        g_snprintf(tmpbuf, BUFFER_SIZE, "%s %d %s.\n", _("Done!"), i-1,
-                ngettext ("event exported", "events exported", i-1));
+    if (count > 0) {
+        g_snprintf(tmpbuf, BUFFER_SIZE, "%s %d %s.\n", _("Done!"), count,
+                ngettext ("event exported", "events exported", count));
 
         utl_gui_create_dialog (GTK_MESSAGE_INFO, tmpbuf, GTK_WINDOW(appGUI->cal->ical_export_window));
     }
