@@ -298,6 +298,7 @@ struct note *a;
 gchar *category, *color_str;
 gint i;
 xmlChar *escaped;
+gboolean has_next;
 
 	if ((appGUI->save_status & WRT_CALENDAR_NOTES) != 0) return;
 
@@ -311,9 +312,8 @@ xmlChar *escaped;
 
 	node = xmlNewChild (main_node, NULL, (const xmlChar *) CALENDAR_DAY_CATEGORIES_NAME, (xmlChar *) NULL);
 
-	i = 0;
-
-	while (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (appGUI->opt->calendar_category_store), &iter, NULL, i++)) {
+	has_next = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (appGUI->opt->calendar_category_store), &iter);
+	while (has_next) {
 		gtk_tree_model_get (GTK_TREE_MODEL (appGUI->opt->calendar_category_store), &iter, 1, &color_str, 2, &category, -1);
 		escaped = xmlEncodeEntitiesReentrant(doc, (const xmlChar *) category);
 		dc_node = xmlNewChild (node, NULL, (const xmlChar *) "name", (xmlChar *) escaped);
@@ -323,6 +323,7 @@ xmlChar *escaped;
 		xmlNewProp (dc_node, (const xmlChar *) "color", (xmlChar *) escaped);
 		g_free (color_str);
         xmlFree (escaped);
+                has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (appGUI->opt->calendar_category_store), &iter);
 	}
 
 	for (i = 0, lnode = appGUI->cal->notes_list; lnode; lnode = lnode->next, i++) {
@@ -587,7 +588,6 @@ GDate *date;
             if (g_date_valid_julian (julian_day) == TRUE) {
 				g_date_set_julian (date, julian_day);
                 cal_jump_to_date (date, appGUI);
-                update_aux_calendars (appGUI);
                 button_day_notes_window_close_cb (NULL, appGUI);
             }
         }
