@@ -770,7 +770,7 @@ calendar_category_add_cb (GtkWidget *widget, GUI *appGUI)
 	const gchar *category_name;
 	gchar category_color[MAXCOLORNAME];
 	gchar *item_color, *item_name;
-	gint i;
+	gboolean has_next;
 
 	category_name = gtk_entry_get_text (GTK_ENTRY (appGUI->opt->calendar_category_entry));
 	if (!strlen (category_name)) return;
@@ -778,8 +778,8 @@ calendar_category_add_cb (GtkWidget *widget, GUI *appGUI)
 	gtk_color_chooser_get_rgba (GTK_COLOR_CHOOSER (appGUI->opt->day_category_color_picker), &color);
 	utl_gui_convert_color_to_string(&color, category_color);
 
-	i = 0;
-	while (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (appGUI->opt->calendar_category_store), &iter, NULL, i++)) {
+	has_next = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (appGUI->opt->calendar_category_store), &iter);
+	while (has_next) {
 		gtk_tree_model_get (GTK_TREE_MODEL (appGUI->opt->calendar_category_store), &iter, 1, &item_color, 2, &item_name, -1);
 		if (!strcmp (category_color, item_color)) {
 			if (!strcmp (category_name, item_name)) {
@@ -790,10 +790,9 @@ calendar_category_add_cb (GtkWidget *widget, GUI *appGUI)
 		}
 		g_free (item_color);
 		g_free (item_name);
+                has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (appGUI->opt->calendar_category_store), &iter);
 	}
 
-	gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (appGUI->opt->calendar_category_store), &iter, NULL, 0);
-
 	image = utl_gui_create_color_swatch (category_color);
 
 	gtk_list_store_append (appGUI->opt->calendar_category_store, &iter);
@@ -1051,22 +1050,22 @@ calendar_ical_files_add_cb (GtkWidget *widget, GUI *appGUI)
 	GtkTreeIter iter;
 	const gchar *ical_name, *ical_filename;
 	gchar *item_filename;
-	gint i = 0;
+	gboolean has_next;
 
 	ical_name = gtk_entry_get_text (GTK_ENTRY (appGUI->opt->calendar_ical_files_name_entry));
 	ical_filename = gtk_entry_get_text (GTK_ENTRY (appGUI->opt->calendar_ical_files_filename_entry));
 
-	while (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (appGUI->opt->calendar_ical_files_store), &iter, NULL, i++)) {
+        has_next = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (appGUI->opt->calendar_ical_files_store), &iter);
+	while (has_next) {
 		gtk_tree_model_get (GTK_TREE_MODEL (appGUI->opt->calendar_ical_files_store), &iter, ICAL_COLUMN_FILENAME, &item_filename, -1);
 		if (!strcmp (ical_filename, item_filename)) {
 			g_free (item_filename);
 			return;
 		}
 		g_free (item_filename);
+                has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (appGUI->opt->calendar_ical_files_store), &iter);
 	}
 
-	gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (appGUI->opt->calendar_category_store), &iter, NULL, 0);
-
 	gtk_list_store_append (appGUI->opt->calendar_ical_files_store, &iter);
 	gtk_list_store_set (appGUI->opt->calendar_ical_files_store, &iter,
 	                    ICAL_COLUMN_NAME, ical_name,
@@ -1576,7 +1575,9 @@ calendar_options_cb (GtkToggleButton *togglebutton, GUI *appGUI)
 #ifdef HAVE_GSPELL
 	config.day_note_spell_checker = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->spell_checker_in_day_notes_checkbutton));
 
-        utl_gui_set_enable_spell_check(appGUI->cal->calendar_note_spelltextview, config.day_note_spell_checker);
+	if (appGUI->cal->calendar_note_spelltextview) {
+	    utl_gui_set_enable_spell_check(appGUI->cal->calendar_note_spelltextview, config.day_note_spell_checker);
+	}
 #endif /* HAVE_GSPELL */
 
 	gui_calendar_set_display_options (GUI_CALENDAR (appGUI->cal->calendar_prev),
