@@ -55,7 +55,7 @@ cal_print_opt_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer user
 {
 	GUI *appGUI = (GUI *) user_data;
 
-	if (event->keyval == GDK_Escape) {
+	if (event->keyval == GDK_KEY_Escape) {
 		window_cal_print_opt_close_cb (widget, NULL, appGUI);
 		return TRUE;
 	}
@@ -98,9 +98,11 @@ cal_print_get_events (gchar *buffer, guint32 julian, GUI *appGUI)
 	gint i;
 
 	gchar *wbuf1, *wbuf2, *stripped;
-	gchar buf1[BUFFER_SIZE], buf2[BUFFER_SIZE];
+	gchar buf1[BUFFER_SIZE];
+#ifdef CONTACTS_ENABLED
 	GDate *date, *sdate;
-	gint age, syear;
+	gint syear;
+#endif  /* CONTACTS_ENABLED */
 	guint32 tsk_julian;
 	gint time;
 	gint max_event_length;
@@ -167,6 +169,7 @@ cal_print_get_events (gchar *buffer, guint32 julian, GUI *appGUI)
 			gtk_tree_model_get (model, &iter, COLUMN_BIRTH_DAY_DATE, &tsk_julian, -1);
 
 			if (g_date_valid_julian (tsk_julian)) {
+				gint age;
 				g_date_set_julian (date, tsk_julian);
 				age = syear - g_date_get_year (date);
 
@@ -178,6 +181,7 @@ cal_print_get_events (gchar *buffer, guint32 julian, GUI *appGUI)
 					g_date_set_year (date, syear);
 
 					if (g_date_compare (date, sdate) == 0) {
+						gchar buf2[BUFFER_SIZE];
 
 						gtk_tree_model_get (model, &iter, COLUMN_FIRST_NAME, &wbuf1, COLUMN_LAST_NAME, &wbuf2, -1);
 						utl_name_strcat (wbuf1, wbuf2, buf2);
@@ -223,6 +227,7 @@ cal_print_get_events (gchar *buffer, guint32 julian, GUI *appGUI)
 					g_date_set_year (date, syear);
 
 					if (g_date_compare (date, sdate) == 0) {
+						gchar buf2[BUFFER_SIZE];
 
 						gtk_tree_model_get (model, &iter, COLUMN_FIRST_NAME, &wbuf1, COLUMN_LAST_NAME, &wbuf2, -1);
 						utl_name_strcat (wbuf1, wbuf2, buf1);
@@ -403,7 +408,11 @@ calendar_draw_page (GtkPrintOperation *operation, GtkPrintContext *context, gint
 			if (actual) {
 				cairo_set_source_rgb (cr, 1.0, 1.0, 1.0);
 			} else {
-				cairo_set_source_rgb (cr, 0.8, 0.8, 0.8);
+				if (config.cal_print_disable_background == FALSE){
+					cairo_set_source_rgb (cr, 0.8, 0.8, 0.8);
+				} else {
+					cairo_set_source_rgb (cr, 1.0, 1.0, 1.0);       /* disabled background */
+				}
 			}
 
 			cairo_fill_preserve (cr);
@@ -437,7 +446,11 @@ calendar_draw_page (GtkPrintOperation *operation, GtkPrintContext *context, gint
 			} else {
 
 				cairo_move_to (cr, day_width * j + padding, header_height + day_height * i + padding);
-				g_snprintf (buffer, BUFFER_SIZE, "<span color=\"white\">%d</span>", day);
+				if (config.cal_print_disable_background == FALSE){
+					g_snprintf (buffer, BUFFER_SIZE, "<span color=\"white\">%d</span>", day);
+				} else {
+					g_snprintf (buffer, BUFFER_SIZE, "<span color=\"gray90\">%d</span>", day);  /* disabled background */
+				}
 				pango_layout_set_markup (layout, buffer, -1);
 				pango_cairo_show_layout (cr, layout);
 
@@ -495,6 +508,8 @@ calendar_print_start_cb (GtkWidget *widget, gpointer user_data)
 	config.cal_print_ical = gtk_toggle_button_get_active
 	    (GTK_TOGGLE_BUTTON (appGUI->cal->print_ical_checkbutton));
 	*/
+	config.cal_print_disable_background = gtk_toggle_button_get_active
+	    (GTK_TOGGLE_BUTTON (appGUI->cal->disable_background_checkbutton));
 
 	gtk_widget_destroy (appGUI->cal->window_print_options);
 
@@ -526,7 +541,6 @@ calendar_create_print_window (GUI *appGUI)
 {
 	GtkWidget *vbox1;
 	GtkWidget *frame1;
-	GtkWidget *alignment;
 	GtkWidget *table_fonts;
 	GtkWidget *month_name_font_button;
 	GtkWidget *day_name_font_button;
@@ -539,7 +553,7 @@ calendar_create_print_window (GUI *appGUI)
 	GtkWidget *vseparator1;
 	GtkWidget *frame3;
 	GtkWidget *table5;
-	GtkObject *spinbutton_adj;
+	GtkAdjustment *spinbutton_adj;
 	GtkWidget *hseparator1;
 	GtkWidget *hbuttonbox;
 	GtkWidget *cancel_button;
@@ -570,7 +584,7 @@ calendar_create_print_window (GUI *appGUI)
 
 	/*---------------------------------------------------------------------------------*/
 
-	vbox1 = gtk_vbox_new (FALSE, 0);
+	vbox1 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_widget_show (vbox1);
 	gtk_container_add (GTK_CONTAINER (appGUI->cal->window_print_options), vbox1);
 
@@ -579,120 +593,108 @@ calendar_create_print_window (GUI *appGUI)
 	gtk_box_pack_start (GTK_BOX (vbox1), frame1, FALSE, FALSE, 2);
 	gtk_frame_set_shadow_type (GTK_FRAME (frame1), GTK_SHADOW_NONE);
 
-	alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
-	gtk_widget_show (alignment);
-	gtk_container_add (GTK_CONTAINER (frame1), alignment);
-	gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
-
-	table_fonts = gtk_table_new (4, 3, FALSE);
+	table_fonts = gtk_grid_new ();
 	gtk_widget_show (table_fonts);
-	gtk_container_add (GTK_CONTAINER (alignment), table_fonts);
-	gtk_table_set_row_spacings (GTK_TABLE (table_fonts), 4);
-	gtk_table_set_col_spacings (GTK_TABLE (table_fonts), 4);
+    gtk_widget_set_margin_left(table_fonts, 12);
+	gtk_container_add (GTK_CONTAINER (frame1), table_fonts);
+	gtk_grid_set_row_spacing (GTK_GRID (table_fonts), 4);
+	gtk_grid_set_column_spacing (GTK_GRID (table_fonts), 4);
 
 	/* table_fonts: row 1 */
 	g_snprintf (buffer, BUFFER_SIZE, "%s:", _("Month name"));
 	label = gtk_label_new (buffer);
 	gtk_widget_show (label);
-	gtk_table_attach (GTK_TABLE (table_fonts), label, 0, 1, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+	gtk_grid_attach (GTK_GRID (table_fonts), label, 0, 0, 1, 1);
+        gtk_widget_set_halign(label, GTK_ALIGN_START);
 
 	appGUI->cal->print_month_name_font_entry = gtk_entry_new ();
-	GTK_WIDGET_UNSET_FLAGS (appGUI->cal->print_month_name_font_entry, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (appGUI->cal->print_month_name_font_entry, FALSE);
 	gtk_widget_show (appGUI->cal->print_month_name_font_entry);
-	gtk_table_attach (GTK_TABLE (table_fonts), appGUI->cal->print_month_name_font_entry, 1, 2, 0, 1,
-	                  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+        gtk_widget_set_hexpand(appGUI->cal->print_month_name_font_entry, TRUE);
+	gtk_grid_attach (GTK_GRID (table_fonts), appGUI->cal->print_month_name_font_entry, 1, 0, 1, 1);
 	gtk_entry_set_text (GTK_ENTRY (appGUI->cal->print_month_name_font_entry), config.cal_print_month_name_font);
 
 	sel1.config = config.cal_print_month_name_font;
 	sel1.entry = appGUI->cal->print_month_name_font_entry;
 
-	month_name_font_button = utl_gui_create_button (GTK_STOCK_SELECT_FONT, OSMO_STOCK_BUTTON_SELECT_FONT, FALSE);
-	GTK_WIDGET_UNSET_FLAGS (month_name_font_button, GTK_CAN_FOCUS);
+	month_name_font_button = gtk_button_new_from_icon_name ("gtk-select-font", GTK_ICON_SIZE_BUTTON);
+	gtk_widget_set_can_focus (month_name_font_button, FALSE);
 	gtk_widget_show (month_name_font_button);
 	g_signal_connect (G_OBJECT (month_name_font_button), "clicked",
 	                  G_CALLBACK (utl_gui_font_select_cb), &sel1);
-	gtk_table_attach (GTK_TABLE (table_fonts), month_name_font_button, 2, 3, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach (GTK_GRID (table_fonts), month_name_font_button, 2, 0, 1, 1);
 
 	/* table_fonts: row 2 */
 	g_snprintf (buffer, BUFFER_SIZE, "%s:", _("Day name"));
 	label = gtk_label_new (buffer);
 	gtk_widget_show (label);
-	gtk_table_attach (GTK_TABLE (table_fonts), label, 0, 1, 1, 2,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+	gtk_grid_attach (GTK_GRID (table_fonts), label, 0, 1, 1,1);
+        gtk_widget_set_halign(label, GTK_ALIGN_START);
 
 	appGUI->cal->print_day_name_font_entry = gtk_entry_new ();
-	GTK_WIDGET_UNSET_FLAGS (appGUI->cal->print_day_name_font_entry, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (appGUI->cal->print_day_name_font_entry, FALSE);
 	gtk_widget_show (appGUI->cal->print_day_name_font_entry);
-	gtk_table_attach (GTK_TABLE (table_fonts), appGUI->cal->print_day_name_font_entry, 1, 2, 1, 2,
-	                  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+        gtk_widget_set_hexpand(appGUI->cal->print_day_name_font_entry, TRUE);
+	gtk_grid_attach (GTK_GRID (table_fonts), appGUI->cal->print_day_name_font_entry, 1, 1, 1, 1);
 	gtk_entry_set_text (GTK_ENTRY (appGUI->cal->print_day_name_font_entry), config.cal_print_day_name_font);
 
 	sel2.config = config.cal_print_day_name_font;
 	sel2.entry = appGUI->cal->print_day_name_font_entry;
 
-	day_name_font_button = utl_gui_create_button (GTK_STOCK_SELECT_FONT, OSMO_STOCK_BUTTON_SELECT_FONT, FALSE);
-	GTK_WIDGET_UNSET_FLAGS (day_name_font_button, GTK_CAN_FOCUS);
+	day_name_font_button = gtk_button_new_from_icon_name ("gtk-select-font", GTK_ICON_SIZE_BUTTON);
+	gtk_widget_set_can_focus (day_name_font_button, FALSE);
 	gtk_widget_show (day_name_font_button);
 	g_signal_connect (G_OBJECT (day_name_font_button), "clicked",
 	                  G_CALLBACK (utl_gui_font_select_cb), &sel2);
-	gtk_table_attach (GTK_TABLE (table_fonts), day_name_font_button, 2, 3, 1, 2,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach (GTK_GRID (table_fonts), day_name_font_button, 2, 1, 1, 1);
 
 	/* table_fonts: row 3 */
 	g_snprintf (buffer, BUFFER_SIZE, "%s:", _("Day number"));
 	label = gtk_label_new (buffer);
 	gtk_widget_show (label);
-	gtk_table_attach (GTK_TABLE (table_fonts), label, 0, 1, 2, 3,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+	gtk_grid_attach (GTK_GRID (table_fonts), label, 0, 2, 1, 1);
+        gtk_widget_set_halign(label, GTK_ALIGN_START);
 
 	appGUI->cal->print_day_num_font_entry = gtk_entry_new ();
-	GTK_WIDGET_UNSET_FLAGS (appGUI->cal->print_day_num_font_entry, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (appGUI->cal->print_day_num_font_entry, FALSE);
 	gtk_widget_show (appGUI->cal->print_day_num_font_entry);
-	gtk_table_attach (GTK_TABLE (table_fonts), appGUI->cal->print_day_num_font_entry, 1, 2, 2, 3,
-	                  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+        gtk_widget_set_hexpand(appGUI->cal->print_day_num_font_entry, TRUE);
+	gtk_grid_attach (GTK_GRID (table_fonts), appGUI->cal->print_day_num_font_entry, 1, 2, 1, 1);
 	gtk_entry_set_text (GTK_ENTRY (appGUI->cal->print_day_num_font_entry), config.cal_print_day_num_font);
 
 	sel3.config = config.cal_print_day_num_font;
 	sel3.entry = appGUI->cal->print_day_num_font_entry;
 
-	day_number_font_button = utl_gui_create_button (GTK_STOCK_SELECT_FONT, OSMO_STOCK_BUTTON_SELECT_FONT, FALSE);
-	GTK_WIDGET_UNSET_FLAGS (day_number_font_button, GTK_CAN_FOCUS);
+	day_number_font_button = gtk_button_new_from_icon_name ("gtk-select-font", GTK_ICON_SIZE_BUTTON);
+	gtk_widget_set_can_focus (day_number_font_button, FALSE);
 	gtk_widget_show (day_number_font_button);
 	g_signal_connect (G_OBJECT (day_number_font_button), "clicked",
 	                  G_CALLBACK (utl_gui_font_select_cb), &sel3);
-	gtk_table_attach (GTK_TABLE (table_fonts), day_number_font_button, 2, 3, 2, 3,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach (GTK_GRID (table_fonts), day_number_font_button, 2, 2, 1, 1);
 
 	/* table_fonts: row 4 */
 	g_snprintf (buffer, BUFFER_SIZE, "%s:", _("Events"));
 	label = gtk_label_new (buffer);
 	gtk_widget_show (label);
-	gtk_table_attach (GTK_TABLE (table_fonts), label, 0, 1, 3, 4,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+	gtk_grid_attach (GTK_GRID (table_fonts), label, 0, 3, 1, 1);
+        gtk_widget_set_halign(label, GTK_ALIGN_START);
 
 	appGUI->cal->print_event_font_entry = gtk_entry_new ();
-	GTK_WIDGET_UNSET_FLAGS (appGUI->cal->print_event_font_entry, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (appGUI->cal->print_event_font_entry, FALSE);
 	gtk_widget_show (appGUI->cal->print_event_font_entry);
-	gtk_table_attach (GTK_TABLE (table_fonts), appGUI->cal->print_event_font_entry, 1, 2, 3, 4,
-	                  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+        gtk_widget_set_hexpand(appGUI->cal->print_event_font_entry, TRUE);
+	gtk_grid_attach (GTK_GRID (table_fonts), appGUI->cal->print_event_font_entry, 1, 3, 1, 1);
 	gtk_entry_set_text (GTK_ENTRY (appGUI->cal->print_event_font_entry), config.cal_print_event_font);
 
 	sel4.config = config.cal_print_event_font;
 	sel4.entry = appGUI->cal->print_event_font_entry;
 
-	event_font_button = utl_gui_create_button (GTK_STOCK_SELECT_FONT, OSMO_STOCK_BUTTON_SELECT_FONT, FALSE);
-	GTK_WIDGET_UNSET_FLAGS (event_font_button, GTK_CAN_FOCUS);
+	event_font_button = gtk_button_new_from_icon_name ("gtk-select-font", GTK_ICON_SIZE_BUTTON);
+	gtk_widget_set_can_focus (event_font_button, FALSE);
 	gtk_widget_show (event_font_button);
 	g_signal_connect (G_OBJECT (event_font_button), "clicked",
 	                  G_CALLBACK (utl_gui_font_select_cb), &sel4);
-	gtk_table_attach (GTK_TABLE (table_fonts), event_font_button, 2, 3, 3, 4,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach (GTK_GRID (table_fonts), event_font_button, 2, 3, 1, 1);
 	/* table_fonts: END */
 
 	g_snprintf (buffer, BUFFER_SIZE, "<b>%s</b>", _("Fonts"));
@@ -701,7 +703,7 @@ calendar_create_print_window (GUI *appGUI)
 	gtk_frame_set_label_widget (GTK_FRAME (frame1), label);
 	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 
-	hbox1 = gtk_hbox_new (FALSE, 0);
+	hbox1 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_widget_show (hbox1);
 	gtk_box_pack_start (GTK_BOX (vbox1), hbox1, TRUE, TRUE, 0);
 
@@ -710,38 +712,34 @@ calendar_create_print_window (GUI *appGUI)
 	gtk_box_pack_start (GTK_BOX (hbox1), frame2, TRUE, TRUE, 2);
 	gtk_frame_set_shadow_type (GTK_FRAME (frame2), GTK_SHADOW_NONE);
 
-	alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
-	gtk_widget_show (alignment);
-	gtk_container_add (GTK_CONTAINER (frame2), alignment);
-	gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
-
-	vbox2 = gtk_vbox_new (FALSE, 0);
+	vbox2 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_widget_show (vbox2);
-	gtk_container_add (GTK_CONTAINER (alignment), vbox2);
+    gtk_widget_set_margin_left(vbox2, 12);
+	gtk_container_add (GTK_CONTAINER (frame2), vbox2);
 
 	appGUI->cal->print_tasks_checkbutton = gtk_check_button_new_with_mnemonic (_("Tasks"));
-	GTK_WIDGET_UNSET_FLAGS (appGUI->cal->print_tasks_checkbutton, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (appGUI->cal->print_tasks_checkbutton, FALSE);
 	gtk_widget_show (appGUI->cal->print_tasks_checkbutton);
 	gtk_box_pack_start (GTK_BOX (vbox2), appGUI->cal->print_tasks_checkbutton, FALSE, FALSE, 0);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->cal->print_tasks_checkbutton),
 	                              config.cal_print_tasks);
 
 	appGUI->cal->print_birthdays_checkbutton = gtk_check_button_new_with_mnemonic (_("Birthdays"));
-	GTK_WIDGET_UNSET_FLAGS (appGUI->cal->print_birthdays_checkbutton, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (appGUI->cal->print_birthdays_checkbutton, FALSE);
 	gtk_widget_show (appGUI->cal->print_birthdays_checkbutton);
 	gtk_box_pack_start (GTK_BOX (vbox2), appGUI->cal->print_birthdays_checkbutton, FALSE, FALSE, 0);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->cal->print_birthdays_checkbutton),
 	                              config.cal_print_birthdays);
 
 	appGUI->cal->print_namedays_checkbutton = gtk_check_button_new_with_mnemonic (_("Namedays"));
-	GTK_WIDGET_UNSET_FLAGS (appGUI->cal->print_namedays_checkbutton, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (appGUI->cal->print_namedays_checkbutton, FALSE);
 	gtk_widget_show (appGUI->cal->print_namedays_checkbutton);
 	gtk_box_pack_start (GTK_BOX (vbox2), appGUI->cal->print_namedays_checkbutton, FALSE, FALSE, 0);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->cal->print_namedays_checkbutton),
 	                              config.cal_print_namedays);
 
 	appGUI->cal->print_day_notes_checkbutton = gtk_check_button_new_with_mnemonic (_("Day notes"));
-	GTK_WIDGET_UNSET_FLAGS (appGUI->cal->print_day_notes_checkbutton, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (appGUI->cal->print_day_notes_checkbutton, FALSE);
 	gtk_widget_show (appGUI->cal->print_day_notes_checkbutton);
 	gtk_box_pack_start (GTK_BOX (vbox2), appGUI->cal->print_day_notes_checkbutton, FALSE, FALSE, 0);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->cal->print_day_notes_checkbutton),
@@ -763,7 +761,7 @@ calendar_create_print_window (GUI *appGUI)
 	gtk_frame_set_label_widget (GTK_FRAME (frame2), label);
 	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 
-	vseparator1 = gtk_vseparator_new ();
+	vseparator1 = gtk_separator_new (GTK_ORIENTATION_VERTICAL);
 	gtk_widget_show (vseparator1);
 	gtk_box_pack_start (GTK_BOX (hbox1), vseparator1, TRUE, TRUE, 0);
 
@@ -778,88 +776,86 @@ calendar_create_print_window (GUI *appGUI)
 	gtk_frame_set_label_widget (GTK_FRAME (frame3), label);
 	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 
-	alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
-	gtk_widget_show (alignment);
-	gtk_container_add (GTK_CONTAINER (frame3), alignment);
-	gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
-
-	table5 = gtk_table_new (2, 2, FALSE);
+	table5 = gtk_grid_new ();
 	gtk_widget_show (table5);
-	gtk_container_add (GTK_CONTAINER (alignment), table5);
-	gtk_table_set_row_spacings (GTK_TABLE (table5), 4);
-	gtk_table_set_col_spacings (GTK_TABLE (table5), 4);
+    gtk_widget_set_margin_left(table5, 12);
+	gtk_container_add (GTK_CONTAINER (frame3), table5);
+	gtk_grid_set_row_spacing (GTK_GRID (table5), 4);
+	gtk_grid_set_column_spacing (GTK_GRID (table5), 4);
 
 	g_snprintf (buffer, BUFFER_SIZE, "%s:", _("Padding"));
 	label = gtk_label_new (buffer);
 	gtk_widget_show (label);
-	gtk_table_attach (GTK_TABLE (table5), label, 0, 1, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+	gtk_grid_attach (GTK_GRID (table5), label, 0, 0, 1, 1);
+        gtk_widget_set_halign(label, GTK_ALIGN_START);
 
 	g_snprintf (buffer, BUFFER_SIZE, "%s:", _("Event maximum length"));
 	label = gtk_label_new (buffer);
 	gtk_widget_show (label);
-	gtk_table_attach (GTK_TABLE (table5), label, 0, 1, 1, 2,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+	gtk_grid_attach (GTK_GRID (table5), label, 0, 1, 1, 1);
+        gtk_widget_set_halign(label, GTK_ALIGN_START);
 
 	spinbutton_adj = gtk_adjustment_new (config.cal_print_padding, 1, 16, 1, 10, 0);
 	appGUI->cal->print_padding_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_adj), 1, 0);
 	gtk_widget_show (appGUI->cal->print_padding_spinbutton);
-	gtk_table_attach (GTK_TABLE (table5), appGUI->cal->print_padding_spinbutton, 1, 2, 0, 1,
-	                  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+    gtk_widget_set_hexpand(appGUI->cal->print_padding_spinbutton, TRUE);
+	gtk_grid_attach (GTK_GRID (table5), appGUI->cal->print_padding_spinbutton, 1, 0, 1, 1);
 
 	spinbutton_adj = gtk_adjustment_new (config.cal_print_event_length, 6, 256, 1, 10, 0);
 	appGUI->cal->print_event_length_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_adj), 1, 0);
 	gtk_widget_show (appGUI->cal->print_event_length_spinbutton);
-	gtk_table_attach (GTK_TABLE (table5), appGUI->cal->print_event_length_spinbutton, 1, 2, 1, 2,
-	                  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+    gtk_widget_set_hexpand(appGUI->cal->print_event_length_spinbutton, TRUE);
+	gtk_grid_attach (GTK_GRID (table5), appGUI->cal->print_event_length_spinbutton, 1, 1, 1, 1);
 
 	label = gtk_label_new (_("Page orientation:"));
 	gtk_widget_show (label);
-	gtk_table_attach (GTK_TABLE (table5), label, 0, 1, 2, 3,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+	gtk_grid_attach (GTK_GRID (table5), label, 0, 2, 1, 1);
+        gtk_widget_set_halign(label, GTK_ALIGN_START);
 
 	appGUI->cal->print_portrait_radiobutton = gtk_radio_button_new_with_mnemonic (NULL, _("Portrait"));
-	GTK_WIDGET_UNSET_FLAGS (appGUI->cal->print_portrait_radiobutton, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (appGUI->cal->print_portrait_radiobutton, FALSE);
 	gtk_widget_show (appGUI->cal->print_portrait_radiobutton);
-	gtk_table_attach (GTK_TABLE (table5), appGUI->cal->print_portrait_radiobutton, 1, 2, 2, 3,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach (GTK_GRID (table5), appGUI->cal->print_portrait_radiobutton, 1, 2, 1, 1);
 	gtk_radio_button_set_group (GTK_RADIO_BUTTON (appGUI->cal->print_portrait_radiobutton), radiobutton_group);
 	radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (appGUI->cal->print_portrait_radiobutton));
 
 	landscape_radiobutton = gtk_radio_button_new_with_mnemonic (NULL, _("Landscape"));
-	GTK_WIDGET_UNSET_FLAGS (landscape_radiobutton, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (landscape_radiobutton, FALSE);
 	gtk_widget_show (landscape_radiobutton);
-	gtk_table_attach (GTK_TABLE (table5), landscape_radiobutton, 1, 2, 3, 4,
-	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	gtk_grid_attach (GTK_GRID (table5), landscape_radiobutton, 1, 3, 1, 1);
 	gtk_radio_button_set_group (GTK_RADIO_BUTTON (landscape_radiobutton), radiobutton_group);
 	radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (landscape_radiobutton));
 
+	appGUI->cal->disable_background_checkbutton = gtk_check_button_new_with_mnemonic (_("Disable background colors"));
+	gtk_widget_set_can_focus (appGUI->cal->disable_background_checkbutton, FALSE);
+	gtk_widget_show (appGUI->cal->disable_background_checkbutton);
+	gtk_grid_attach (GTK_GRID (table5), appGUI->cal->disable_background_checkbutton, 0, 4, 1, 1);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->cal->disable_background_checkbutton),
+	                              config.cal_print_disable_background);
+
 	if (config.cal_print_page_orientation == PORTRAIT) {
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->cal->print_portrait_radiobutton), TRUE);
 	} else {
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (landscape_radiobutton), TRUE);
 	}
 
-	hseparator1 = gtk_hseparator_new ();
+	hseparator1 = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
 	gtk_widget_show (hseparator1);
 	gtk_box_pack_start (GTK_BOX (vbox1), hseparator1, FALSE, TRUE, 4);
 
-	hbuttonbox = gtk_hbutton_box_new ();
+	hbuttonbox = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
 	gtk_widget_show (hbuttonbox);
 	gtk_box_pack_start (GTK_BOX (vbox1), hbuttonbox, FALSE, FALSE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (hbuttonbox), 4);
 	gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
 	gtk_box_set_spacing (GTK_BOX (hbuttonbox), 16);
 
-	cancel_button = utl_gui_create_labeled_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel"));
+	cancel_button = gtk_button_new_with_mnemonic (_("_Cancel"));
 	gtk_widget_show (cancel_button);
 	g_signal_connect (cancel_button, "clicked", G_CALLBACK (window_button_cal_print_opt_close_cb), appGUI);
 	gtk_container_add (GTK_CONTAINER (hbuttonbox), cancel_button);
 
-	ok_button = utl_gui_create_labeled_button (GTK_STOCK_OK, OSMO_STOCK_BUTTON_OK, _("OK"));
+	ok_button = gtk_button_new_with_mnemonic (_("_OK"));
 	gtk_widget_show (ok_button);
 	g_signal_connect (ok_button, "clicked", G_CALLBACK (calendar_print_start_cb), appGUI);
 	gtk_container_add (GTK_CONTAINER (hbuttonbox), ok_button);
