@@ -22,7 +22,7 @@
 #ifndef _CALENDAR_PRINT_H
 #define _CALENDAR_PRINT_H
 
-void    calendar_print     (GUI *appGUI);
+void    calendar_create_print_window     (GUI *appGUI);
 
 
 #endif /* _CALENDAR_PRINT_H */
