@@ -34,18 +34,15 @@
 #ifndef _CALENDAR_WIDGET_H
 #define _CALENDAR_WIDGET_H
 
-#include <gdk/gdk.h>
-#include <gtk/gtkwidget.h>
-
-/* Not needed, retained for compatibility -Yosh */
-#include <gtk/gtksignal.h>
+#include <glib-object.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
 /* Spacing around day/week headers and main area, inside those windows */
 #define CALENDAR_MARGIN      0
 /* Spacing around day/week headers and main area, outside those windows */
-#define INNER_BORDER         1
+#define INNER_BORDER         2
 /* Separation between day headers and main area */
 #define CALENDAR_YSEP        4
 /* Separation between week headers and main area */
@@ -56,18 +53,6 @@ G_BEGIN_DECLS
 
 #define SCROLL_DELAY_FACTOR  5
 
-/* Color usage */
-#define HEADER_FG_COLOR(widget)      (& (widget)->style->fg[GTK_WIDGET_STATE (widget)])
-#define HEADER_BG_COLOR(widget)      (& (widget)->style->bg[GTK_WIDGET_STATE (widget)])
-#define SELECTED_BG_COLOR(widget)    (& (widget)->style->base[GTK_WIDGET_HAS_FOCUS (widget) ? GTK_STATE_SELECTED : GTK_STATE_ACTIVE])
-#define SELECTED_FG_COLOR(widget)    (& (widget)->style->text[GTK_WIDGET_HAS_FOCUS (widget) ? GTK_STATE_SELECTED : GTK_STATE_ACTIVE])
-#define NORMAL_DAY_COLOR(widget)     (& (widget)->style->fg[GTK_WIDGET_STATE (widget)])
-#define PREV_MONTH_COLOR(widget)     (& (widget)->style->mid[GTK_WIDGET_STATE (widget)])
-#define NEXT_MONTH_COLOR(widget)     (& (widget)->style->mid[GTK_WIDGET_STATE (widget)])
-#define MARKED_COLOR(widget)         (& (widget)->style->fg[GTK_WIDGET_STATE (widget)])
-#define BACKGROUND_COLOR(widget)     (& (widget)->style->base[GTK_WIDGET_STATE (widget)])
-#define HIGHLIGHT_BACK_COLOR(widget) (& (widget)->style->mid[GTK_WIDGET_STATE (widget)])
-
 #define GUI_TYPE_CALENDAR                  (gui_calendar_get_type ())
 #define GUI_CALENDAR(obj)                  (G_TYPE_CHECK_INSTANCE_CAST ((obj), GUI_TYPE_CALENDAR, GuiCalendar))
 #define GUI_CALENDAR_CLASS(klass)          (G_TYPE_CHECK_CLASS_CAST ((klass), GUI_TYPE_CALENDAR, GuiCalendarClass))
@@ -153,12 +138,16 @@ enum {
 };
 
 enum {
-	HEADER_COLOR = 0,
+	HEADER_BG_COLOR = 0,
+	HEADER_FG_COLOR,
 	WEEKEND_COLOR,
 	SELECTOR_COLOR,
 	EVENT_MARKER_COLOR,
 	TODAY_MARKER_COLOR,
-	BIRTHDAY_MARKER_COLOR
+	BIRTHDAY_MARKER_COLOR,
+	DAY_COLOR,
+	PF_DAY_COLOR,
+	BACKGROUND_COLOR
 };
 
 struct _GuiCalendarPrivate {
@@ -172,7 +161,7 @@ struct _GuiCalendarPrivate {
     guint day_name_h;
     guint main_h;
 
-    guint arrow_state[4];
+    GtkStateFlags arrow_state[4];
     guint arrow_width;
     guint max_month_width;
     guint max_year_width;
@@ -229,16 +218,18 @@ struct _GuiCalendar {
     gint birthday_marked_date[31];
 
     GuiCalendarDisplayOptions  display_flags;
-    GdkColor marked_date_color[31];
+    GdkRGBA marked_date_color[31];
 
-    GdkColor header_color;
-    GdkColor weekend_color;
-    GdkColor selector_color;
-    GdkColor event_marker_color;
-    GdkColor today_marker_color;
-    GdkColor birthday_marker_color;
-	gint selector_alpha;
-	gint today_marker_alpha;
+    GdkRGBA background_color;
+    GdkRGBA header_bg_color;
+    GdkRGBA header_fg_color;
+    GdkRGBA weekend_color;
+    GdkRGBA selector_color;
+    GdkRGBA event_marker_color;
+    GdkRGBA today_marker_color;
+    GdkRGBA birthday_marker_color;
+    GdkRGBA day_color;
+    GdkRGBA pf_day_color;
 
     gunichar mark_sign;
     gint cursor_type;
@@ -248,9 +239,6 @@ struct _GuiCalendar {
 
     gboolean enable_cursor;
 
-    GdkGC *gc;          /* unused */
-    GdkGC *xor_gc;      /* unused */
-
     gint focus_row;
     gint focus_col;
 
