@@ -522,6 +522,7 @@ show_task_notification(TASK_NTF *notification, gboolean notification_enabled, gb
         GError *err = NULL;
         if (!notify_notification_show(notification->notify, &err)) {
             g_warning("Failed to send notification: %s", err->message);
+            g_error_free (err);
             return;
         }
     }
@@ -594,19 +595,20 @@ static void
 notify_tasks(GUI *appGUI) {
     GtkTreeIter iter;
     TASK_ITEM *item;
-    gint i = 0;
-    gboolean play_sound = TRUE;
+    gboolean play_sound = TRUE, has_next;
 
     if (appGUI->tsk->notifications_enable == FALSE) {
         return;
     }
 
-    while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter, NULL, i++)) {
+    has_next = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter);
+    while (has_next) {
         gboolean task_notified;
         item = tsk_get_item(&iter, appGUI);
         task_notified = check_task_notification(item, play_sound, appGUI);
         play_sound = play_sound && !task_notified;
         tsk_item_free(item);
+        has_next=gtk_tree_model_iter_next(GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter);
     }
 }
 
@@ -616,11 +618,12 @@ static void
 ignore_offline_tasks(GUI *appGUI) {
     GtkTreeIter iter;
     TASK_ITEM *item;
-    gint i = 0;
     guint32 now_date = utl_date_get_current_julian ();
     gint now_time = utl_time_get_current_seconds ();
+    gboolean valid;
 
-    while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter, NULL, i++)) {
+    valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter);
+    while (valid) {
         item = tsk_get_item(&iter, appGUI);
         if (item->repeat == TRUE && item->offline_ignore == TRUE) {
             if (utl_date_time_compare_js(item->due_date_julian, item->due_time, now_date, now_time) < 0) {
@@ -628,6 +631,7 @@ ignore_offline_tasks(GUI *appGUI) {
             }
         }
         tsk_item_free(item);
+        valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter);
     }
 }
 
@@ -638,9 +642,12 @@ delete_task_notification(guint id, GUI *appGUI) {
 #ifdef HAVE_LIBNOTIFY
     TASK_NTF *a = get_task_notification(id, appGUI);
     if (a != NULL) {
-        GError *err = NULL;
-        if(!notify_notification_close(a->notify, &err)) {
-            g_warning("Failed to close notification: %s", err->message);
+        if (a->notify) {
+            GError *err = NULL;
+            if (!notify_notification_close(a->notify, &err)) {
+                g_warning("Failed to close notification: %s", err->message);
+                g_error_free (err);
+            }
         }
         appGUI->tsk->notifications = g_slist_remove(appGUI->tsk->notifications, a);
         g_free(a);
@@ -841,7 +848,6 @@ GDate *date;
 		if (g_date_valid_julian (julian_day) == TRUE) {
 			g_date_set_julian (date, julian_day);
 			cal_jump_to_date (date, appGUI);
-			update_aux_calendars (appGUI);
 			gtk_notebook_set_current_page (GTK_NOTEBOOK (appGUI->notebook), PAGE_CALENDAR);
 			button_event_checker_show_osmo_window_cb (NULL, appGUI);
 		}
