@@ -51,12 +51,12 @@ typedef struct {
 #endif  /* HAVE_LIBNOTIFY */
 
 void        free_notifications_list         (GUI *appGUI);
-gboolean    time_handler                    (GUI *appGUI);
+gboolean    time_handler                    (gpointer data);
 gboolean    check_contacts                  (guint32 julian_day, GUI *appGUI);
 gboolean    check_tasks_contacts            (guint32 julian_day, GUI *appGUI);
 gboolean    create_event_checker_window     (GUI *appGUI);
 
-void        notify_task                     (TASK_ITEM *item, GUI *appGUI);
-void        notify_task_delete              (guint id, GUI *appGUI);
+void        change_task_notification        (TASK_ITEM *item, GUI *appGUI);
+void        delete_task_notification        (guint id, GUI *appGUI);
 #endif /* _CHECK_EVENTS_H */
 
