@@ -620,10 +620,10 @@ choose_strategy(gint type, gboolean header) {
 
 gint
 export_contacts(gint type, gboolean header, GUI *appGUI, export_writer *writer, void *writer_user_data) {
-    GtkTreePath *sort_path, *filter_path, *path;
+    GtkTreeIter sort_iter;
+    gboolean valid;
     gint i, exported;
     gchar *text;
-    GtkTreeIter iter;
     guint32 date;
     struct contact_export_strategy *strategy;
 
@@ -634,61 +634,38 @@ export_contacts(gint type, gboolean header, GUI *appGUI, export_writer *writer,
     if (strategy) {
         strategy->begin_file(appGUI, writer, writer_user_data);
 
-        sort_path = gtk_tree_path_new_first();
+        valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(appGUI->cnt->contacts_sort), &sort_iter);
+        while (valid) {
+            GtkTreeIter filter_iter, iter;
+            gtk_tree_model_sort_convert_iter_to_child_iter(GTK_TREE_MODEL_SORT(appGUI->cnt->contacts_sort), &filter_iter, &sort_iter);
+            gtk_tree_model_filter_convert_iter_to_child_iter(GTK_TREE_MODEL_FILTER(appGUI->cnt->contacts_filter), &iter, &filter_iter);
+            strategy->begin_contact(exported, appGUI, writer, writer_user_data);
 
-        while (gtk_tree_model_get_iter(GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter, sort_path) == TRUE) {
+            for (i = 0; i < CONTACTS_NUM_COLUMNS; i++) {
+                if (is_export_column(i)) {
 
-            if (sort_path != NULL) {
-
-                filter_path = gtk_tree_model_sort_convert_path_to_child_path(GTK_TREE_MODEL_SORT(appGUI->cnt->contacts_sort), sort_path);
-
-                if (filter_path != NULL) {
-
-                    path = gtk_tree_model_filter_convert_path_to_child_path(GTK_TREE_MODEL_FILTER(appGUI->cnt->contacts_filter), filter_path);
-
-                    if (path != NULL) {
-
-                        gtk_tree_model_get_iter(GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter, path);
-
-                        strategy->begin_contact(exported, appGUI, writer, writer_user_data);
-
-                        for (i = 0; i < CONTACTS_NUM_COLUMNS; i++) {
-
-                            if (is_export_column(i)) {
-
-                                if (i == COLUMN_BIRTH_DAY_DATE || i == COLUMN_NAME_DAY_DATE) {
-                                    gtk_tree_model_get(GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter, i, &date, -1);
-                                    if (date == 0) {
-                                        text = NULL;
-                                    } else {
-                                        if (i == COLUMN_BIRTH_DAY_DATE) {
-                                            text = g_strdup((const gchar *) julian_to_str(date, DATE_DD_MM_YYYY, TRUE));
-                                        } else {
-                                            text = g_strdup((const gchar *) julian_to_str(date, DATE_DD_MM_YYYY, TRUE));
-                                        }
-                                    }
-                                } else {
-                                    gtk_tree_model_get(GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter, i, &text, -1);
-                                }
-
-                                strategy->handle_contact_value(i, text, &iter, appGUI, writer, writer_user_data);
-                                g_free(text);
+                    if (i == COLUMN_BIRTH_DAY_DATE || i == COLUMN_NAME_DAY_DATE) {
+                        gtk_tree_model_get(GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter, i, &date, -1);
+                        if (date == 0) {
+                            text = NULL;
+                        } else {
+                            if (i == COLUMN_BIRTH_DAY_DATE) {
+                                text = g_strdup((const gchar *) julian_to_str(date, DATE_DD_MM_YYYY, TRUE));
+                            } else {
+                                text = g_strdup((const gchar *) julian_to_str(date, DATE_DD_MM_YYYY, TRUE));
                             }
                         }
-
-                        strategy->end_contact(exported, appGUI, writer, writer_user_data);
-
-                        exported++;
-                        gtk_tree_path_free(path);
-
+                    } else {
+                        gtk_tree_model_get(GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter, i, &text, -1);
                     }
 
-                    gtk_tree_path_free(filter_path);
+                    strategy->handle_contact_value(i, text, &iter, appGUI, writer, writer_user_data);
+                    g_free(text);
                 }
-
             }
-
-            gtk_tree_path_next(sort_path);
+            strategy->end_contact(exported, appGUI, writer, writer_user_data);
+            exported++;
+            valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(appGUI->cnt->contacts_sort), &sort_iter);
         }
 
         strategy->end_file(appGUI, writer, writer_user_data);
