@@ -35,9 +35,10 @@ enum {
     SELECT_NONE,
     SELECT_INVERT
 };
+typedef void(export_writer) (void *user_data, gchar const *format, ...);
 
-gboolean    export_contacts_to_file         (gchar *filename, gboolean header, GUI *appGUI);
-void        contacts_create_export_window   (GUI *appGUI);
+gint export_contacts(gint type, gboolean header, GUI *appGUI, export_writer *writer, void *writer_user_data);
+void contacts_create_export_window(GUI *appGUI);
 
 #endif /* _CONTACTS_EXPORT_H */
 
