@@ -415,7 +415,7 @@ type_changed_cb (GtkComboBox *widget, gpointer user_data) {
 void
 start_import_cb (GtkWidget *widget, gpointer data) {
 
-gint i, j, k, n, m, p, w;
+gint i, j, k, n, p, w;
 guint n_records;
 gchar *str, *field_str, *item, *text;
 gchar ch[2] = { 0, 0 };
@@ -474,9 +474,9 @@ gchar tmpbuf[BUFFER_SIZE];
                         } else if (appGUI->cnt->field_type[i]-1 == COLUMN_GROUP) {
                             /* set group */
                             if(p) {
-                                m = 0;
+                                gboolean has_next = gtk_tree_model_get_iter_first (GTK_TREE_MODEL(appGUI->opt->contacts_group_store), &g_iter);
                                 g_flag = TRUE;
-                                while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->opt->contacts_group_store), &g_iter, NULL, m++)) {
+                                while (has_next) {
                                     gtk_tree_model_get(GTK_TREE_MODEL(appGUI->opt->contacts_group_store), &g_iter, 0, &item, -1);
                                     if (!strcmp(field_str, item)) {
                                         g_free(item);
@@ -484,9 +484,9 @@ gchar tmpbuf[BUFFER_SIZE];
                                         break;
                                     }
                                     g_free(item);
+                                    has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL(appGUI->opt->contacts_group_store), &g_iter);
                                 }
                                 if (g_flag == TRUE) {
-                                    gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->opt->contacts_group_store), &g_iter, NULL, 0);
                                     gtk_list_store_append(appGUI->opt->contacts_group_store, &g_iter);
                                     gtk_list_store_set(appGUI->opt->contacts_group_store, &g_iter, 0, field_str, -1);
                                 }
