@@ -22,15 +22,21 @@
 #ifndef _CONTACTS_IMPORT_H
 #define _CONTACTS_IMPORT_H
 
-#define     MAX_LINE_LENGTH         32768       /* number of chars per line */
-#define     MAX_FIELD_LENGTH        8192        /* number of chars per field */
-#define     FIELD_SEPARATOR         ','
+#include "gui.h"
 
+enum {
+    IMPORT_TYPE_FILE = 0,
+    IMPORT_TYPE_SYNCML
+};
+
+enum {
+    SYNCML_BLUETOOTH = 0,
+    SYNCML_USB
+};
+
+void        import_contacts_show_dialog     (GUI *appGUI);
 gboolean    import_contacts_from_csv_file   (GUI *appGUI);
 gboolean    add_csv_records                 (gchar *filename, GUI *appGUI);
-gchar *     csv_get_field                   (gchar *line_buffer, guint field);
-gchar *     csv_get_line                    (guint line, GUI *appGUI);
-guint       get_number_of_records           (GUI *appGUI);
 
 #endif /* _CONTACTS_IMPORT_H */
 
