@@ -41,11 +41,13 @@ void
 contacts_fill_ids (GUI *appGUI) {
 
 GtkTreeIter iter;
-gint i;
+gint i = 0;
+gboolean has_next;
 
-    i = 0;
-    while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter, NULL, i++)) {
-        gtk_list_store_set(appGUI->cnt->contacts_list_store, &iter, COLUMN_ID, i, -1);
+    has_next = gtk_tree_model_get_iter_first (GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter);
+    while (has_next) {
+        gtk_list_store_set(appGUI->cnt->contacts_list_store, &iter, COLUMN_ID, ++i, -1);
+        has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter);
     }
 
 }
@@ -678,7 +680,7 @@ gchar *contact_replace_tags[] = {
         if (i == COLUMN_FIRST_NAME) {
             appGUI->cnt->next_field_button[i] = gtk_button_new_from_icon_name ("go-down", GTK_ICON_SIZE_BUTTON);
             gtk_widget_show (appGUI->cnt->next_field_button[i]);
-            gtk_widget_set_can_focus(appGUI->cnt->next_field_button[i], false);
+            gtk_widget_set_can_focus(appGUI->cnt->next_field_button[i], FALSE);
         }
 
         gtk_widget_show (appGUI->cnt->contact_entries[i]);
@@ -1233,8 +1235,7 @@ gchar tmpbuf[BUFFER_SIZE];
 
 void
 write_contacts_entries (GUI *appGUI) {
-
-gint i, j;
+gboolean has_next;
 xmlDocPtr doc;
 xmlNodePtr main_node, node, note_node;
 xmlAttrPtr attr;
@@ -1255,39 +1256,39 @@ gchar tmpbuf[BUFFER_SIZE];
 
     node = xmlNewChild (main_node, NULL, (const xmlChar *) CONTACTS_GROUP_ENTRIES_NAME, (xmlChar *) NULL);
 
-    i = 0;
-
-    while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->opt->contacts_group_store), &iter, NULL, i++)) {
+    has_next = gtk_tree_model_get_iter_first (GTK_TREE_MODEL(appGUI->opt->contacts_group_store), &iter);
+    while (has_next) {
         gtk_tree_model_get (GTK_TREE_MODEL(appGUI->opt->contacts_group_store), &iter, 0, &item, -1);
         utl_xml_put_str ("name", item, node);
         g_free (item);
+        has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL(appGUI->opt->contacts_group_store), &iter);
     }
 
     node = xmlNewChild (main_node, NULL, (const xmlChar *) CONTACTS_ENTRIES_NAME, (xmlChar *) NULL);
 
-    i = 0;
-
-    while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter, NULL, i++)) {
+    has_next = gtk_tree_model_get_iter_first (GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter);
+    while (has_next) {
+        gint i;
 
         note_node = xmlNewChild (node, NULL, (const xmlChar *) "record", (xmlChar *) NULL);
 
-        for (j = COLUMN_GROUP; j < CONTACTS_NUM_COLUMNS; j++) {
+        for (i = COLUMN_GROUP; i < CONTACTS_NUM_COLUMNS; i++) {
 
-            if (j != COLUMN_ID) {
+            if (i != COLUMN_ID) {
 
-                if (j == COLUMN_BIRTH_DAY_DATE || j == COLUMN_NAME_DAY_DATE) {
+                if (i == COLUMN_BIRTH_DAY_DATE || i == COLUMN_NAME_DAY_DATE) {
 
-                    gtk_tree_model_get (GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter, j, &date, -1);
+                    gtk_tree_model_get (GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter, i, &date, -1);
                     g_snprintf(tmpbuf, BUFFER_SIZE, "%d", date);
-                    utl_xml_put_str (appGUI->cnt->contact_fields_tags_name[j*2+1], tmpbuf, note_node);
+                    utl_xml_put_str (appGUI->cnt->contact_fields_tags_name[i*2+1], tmpbuf, note_node);
 
                 } else {
 
-                    gtk_tree_model_get (GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter, j, &item, -1);
+                    gtk_tree_model_get (GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter, i, &item, -1);
 
                     if (item != NULL) {
                         if (strlen(item)) {
-                            utl_xml_put_str (appGUI->cnt->contact_fields_tags_name[j*2+1], item, note_node);
+                            utl_xml_put_str (appGUI->cnt->contact_fields_tags_name[i*2+1], item, note_node);
                         }
                     }
 
@@ -1295,6 +1296,7 @@ gchar tmpbuf[BUFFER_SIZE];
                 }
             }
         }
+        has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter);
     }
 
     utl_xml_write_doc (prefs_get_data_filename(CONTACTS_ENTRIES_FILENAME, appGUI), doc);
