@@ -24,12 +24,9 @@
 
 #include "gui.h"
 
-#define CONTACTS_ADD_EDIT_WINDOW_SIZE_X    500
-#define CONTACTS_ADD_EDIT_WINDOW_SIZE_Y    600
-
 void    read_contacts_entries           (GUI *appGUI);
 void    write_contacts_entries          (GUI *appGUI);
-void    contacts_remove_dialog_show     (GtkWidget *list, GtkListStore *list_store, GUI *appGUI);
+void    contacts_remove_dialog_show     (GUI *appGUI);
 void    contacts_add_edit_dialog_show   (gboolean contacts_edit_mode, GUI *appGUI);
 
 #endif /* _CONTACTS_ITEMS_H */
