@@ -50,7 +50,6 @@
 #include "calendar_preferences_gui.h"
 #include "config.h"
 
-#include "gui_icon.h"
 #ifndef WIN32
 #include <glib-unix.h>
 #endif /* WIN32 */
@@ -1482,7 +1481,6 @@ gui_create_window (GUI *appGUI)
     GdkScreen *screen;
     gint sw, sh;
     gint fdSTDERR, fdSTDERRn;
-    GdkPixbuf *icon;
 
     /* disable STDERR temporary - to suppress messages from webkit */
     fdSTDERR = dup (STDERR_FILENO);
@@ -1506,9 +1504,7 @@ gui_create_window (GUI *appGUI)
 
     gtk_widget_set_events(appGUI->main_window, GDK_BUTTON_PRESS_MASK | GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK);
 
-    icon = gdk_pixbuf_new_from_inline(-1, osmo_icon, FALSE, NULL);
-    gtk_window_set_icon (GTK_WINDOW(appGUI->main_window), icon);
-    g_object_unref(icon);
+    gtk_window_set_icon_name(GTK_WINDOW(appGUI->main_window), OSMO_STOCK_LOGO);
 
     screen = gdk_screen_get_default ();
     if (screen != NULL) {
@@ -1637,9 +1633,7 @@ gui_create_window (GUI *appGUI)
     }
 
     appGUI->all_pages_added = TRUE;
-    calendar_set_today (appGUI);
-
-    update_aux_calendars (appGUI);
+    cal_refresh_notes(appGUI);
 
     if (config.toolbar_exit_button == FALSE) {
         if (appGUI->calendar_only == FALSE) {
