@@ -161,21 +161,20 @@ GtkTreeModel *model;
 	text = (unsigned char*) utl_gui_text_buffer_get_text_with_tags (buffer);
 
 	if (appGUI->nte->encrypted == TRUE) {
-
 #ifdef HAVE_LIBGRINGOTTS
-	if (appGUI->nte->keyholder != NULL && appGUI->nte->context != NULL && appGUI->nte->filename != NULL) {
-        grg_encrypt_file (appGUI->nte->context, appGUI->nte->keyholder,
-						  (unsigned char*) notes_get_full_filename(appGUI->nte->filename, appGUI), 
-						  (guchar *) text, -1);
-
-        grg_free (appGUI->nte->context, text, -1);
-	}
+            if (appGUI->nte->keyholder != NULL && appGUI->nte->context != NULL && appGUI->nte->filename != NULL) {
+                grg_encrypt_file(appGUI->nte->context, appGUI->nte->keyholder,
+                        (unsigned char*) notes_get_full_filename(appGUI->nte->filename, appGUI),
+                        (guchar *) text, -1);
+                grg_free(appGUI->nte->context, text, -1);
+            } else {
+                g_free(text);
+            }
 #endif /* HAVE_LIBGRINGOTTS */
-
 	} else {
-
-		g_file_set_contents (notes_get_full_filename(appGUI->nte->filename, appGUI), 
-							 (gchar *) text, strlen((gchar *) text), NULL);
+            g_file_set_contents (notes_get_full_filename(appGUI->nte->filename, appGUI), 
+                                                     (gchar *) text, strlen((gchar *) text), NULL);
+            g_free(text);
 	}
 
 	appGUI->nte->changed = FALSE;
@@ -359,7 +358,7 @@ gchar tmpbuf[BUFFER_SIZE];
 
 	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview));
 	gtk_text_buffer_get_selection_bounds (buffer, &start, &end);
-    text = gtk_text_buffer_get_text (GTK_TEXT_BUFFER (buffer), &start, &end, FALSE);
+        text = gtk_text_buffer_get_text (GTK_TEXT_BUFFER (buffer), &start, &end, FALSE);
 
 	n = utl_open_count_url_links (text, TRUE);
 
@@ -399,6 +398,7 @@ gchar tmpbuf[BUFFER_SIZE];
 			}
 		}
 	}
+        g_free(text);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -841,15 +841,10 @@ notes_category_combo_box_focus_cb (GtkWidget *widget, GtkDirectionType *arg1, gp
 
 void
 update_notes_items (GUI *appGUI) {
-
-GtkTreeIter iter;
 gint i;
 gchar tmpbuf[BUFFER_SIZE];
 
-    i = 0;
-
-    while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->nte->notes_filter), &iter, NULL, i++));
-    --i;
+    i = gtk_tree_model_iter_n_children (GTK_TREE_MODEL(appGUI->nte->notes_filter), NULL);
 
     if (!i) {
         g_snprintf(tmpbuf, BUFFER_SIZE, "<i>%s</i>", _("no entries"));
@@ -867,14 +862,13 @@ void
 refresh_notes (GUI *appGUI) {
 
 GtkTreeIter iter;
-gint i;
+gboolean has_next;
 guint32 last_changes_date, create_date;
 gint last_changes_time, create_time;
 gchar *last_changes_time_str, *create_time_str;
 
-    i = 0;
-
-    while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->nte->notes_list_store), &iter, NULL, i++)) {
+    has_next = gtk_tree_model_get_iter_first (GTK_TREE_MODEL(appGUI->nte->notes_list_store), &iter);
+    while (has_next) {
 
         gtk_tree_model_get(GTK_TREE_MODEL(appGUI->nte->notes_list_store), &iter,
                 N_COLUMN_LAST_CHANGES_DATE_JULIAN, &last_changes_date,
@@ -889,6 +883,7 @@ gchar *last_changes_time_str, *create_time_str;
                 N_COLUMN_CREATE_DATE, create_time_str, -1);
         g_free(last_changes_time_str);
         g_free(create_time_str);
+        has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL(appGUI->nte->notes_list_store), &iter);
     }
 
     update_notes_items(appGUI);
@@ -1224,19 +1219,14 @@ notes_search_entry_changed_cb (GtkWidget *widget, GdkEventKey *event, gpointer u
 
 GtkTreePath *path;
 GtkTreeIter iter;
-gint i;
 
     GUI *appGUI = (GUI *)user_data;
 
     gtk_tree_model_filter_refilter(GTK_TREE_MODEL_FILTER(appGUI->nte->notes_filter));
 
     if(strlen(gtk_entry_get_text (GTK_ENTRY(appGUI->nte->notes_find_entry)))) {
-
-		i = 0;
-		while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->nte->notes_filter), &iter, NULL, i++));
-
-		if (i-1 != 0) {
-
+		gboolean has_next = gtk_tree_model_get_iter_first (GTK_TREE_MODEL(appGUI->nte->notes_filter), &iter);
+		if (has_next) {
 			path = gtk_tree_path_new_first();
 			if (path != NULL) {
 				gtk_tree_view_set_cursor (GTK_TREE_VIEW (appGUI->nte->notes_list), path, NULL, FALSE);
@@ -1576,7 +1566,6 @@ gint nt_columns[MAX_VISIBLE_NOTE_COLUMNS] = {
     gtk_tree_view_set_enable_search (GTK_TREE_VIEW(appGUI->nte->notes_list), FALSE);
     gtk_widget_show (appGUI->nte->notes_list);
     gtk_widget_set_can_default (appGUI->nte->notes_list, TRUE);
-    gtk_container_add (GTK_CONTAINER (appGUI->nte->scrolled_win), appGUI->nte->notes_list);
 
     g_signal_connect(G_OBJECT(appGUI->nte->notes_list), "button_press_event",
                      G_CALLBACK(notes_list_dbclick_cb), appGUI);
@@ -1723,27 +1712,29 @@ gint nt_columns[MAX_VISIBLE_NOTE_COLUMNS] = {
             NULL);
     gtk_tree_view_column_set_visible(appGUI->nte->notes_columns[N_COLUMN_ENCRYPTED], FALSE);
     gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->nte->notes_list), appGUI->nte->notes_columns[N_COLUMN_ENCRYPTED]);
-	/* restore columns order */
 
-	columns_order[0] = config.notes_column_idx_0;
-	columns_order[1] = config.notes_column_idx_1;
-	columns_order[2] = config.notes_column_idx_2;
-	columns_order[3] = config.notes_column_idx_3;
-	columns_order[4] = config.notes_column_idx_4;
+    /* restore columns order */
+    columns_order[0] = config.notes_column_idx_0;
+    columns_order[1] = config.notes_column_idx_1;
+    columns_order[2] = config.notes_column_idx_2;
+    columns_order[3] = config.notes_column_idx_3;
+    columns_order[4] = config.notes_column_idx_4;
 
-	n = MAX_VISIBLE_NOTE_COLUMNS-1;
+    n = MAX_VISIBLE_NOTE_COLUMNS - 1;
 
-	while (n >= 0) {
-		for (i = 0; i < MAX_VISIBLE_NOTE_COLUMNS; i++) {
-			if (n == columns_order[i]) {
-				gtk_tree_view_move_column_after(GTK_TREE_VIEW(appGUI->nte->notes_list),
-                                        appGUI->nte->notes_columns[nt_columns[i]], NULL);
-				n--;
-			}
-		}
-	}
+    while (n >= 0) {
+        for (i = 0; i < MAX_VISIBLE_NOTE_COLUMNS; i++) {
+            if (n == columns_order[i]) {
+                gtk_tree_view_move_column_after(GTK_TREE_VIEW(appGUI->nte->notes_list),
+                        appGUI->nte->notes_columns[nt_columns[i]], NULL);
+                n--;
+            }
+        }
+    }
 
-	set_note_columns_width (appGUI);
+    set_note_columns_width(appGUI);
+
+    gtk_container_add(GTK_CONTAINER(appGUI->nte->scrolled_win), appGUI->nte->notes_list);
 
     /* configure sorting */
     for (i = 0; i < MAX_VISIBLE_NOTE_COLUMNS; i++) {
@@ -1980,15 +1971,12 @@ void
 check_notes_type (GUI *appGUI) {
 
 GtkTreeIter iter;
-gint i;
 gchar *filename;
 GdkPixbuf *image;
-gboolean encrypted;
-
-    i = 0;
-
-    while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->nte->notes_list_store), &iter, NULL, i++)) {
+gboolean encrypted, has_next;
 
+    has_next = gtk_tree_model_get_iter_first (GTK_TREE_MODEL(appGUI->nte->notes_list_store), &iter);
+    while (has_next) {
         gtk_tree_model_get(GTK_TREE_MODEL(appGUI->nte->notes_list_store), &iter,
                 N_COLUMN_FILENAME, &filename, -1);
 
@@ -2002,6 +1990,7 @@ gboolean encrypted;
         g_free(filename);
         gtk_list_store_set(appGUI->nte->notes_list_store, &iter, N_COLUMN_TYPE, image, N_COLUMN_ENCRYPTED, encrypted, -1);
         g_object_unref(image);
+        has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL(appGUI->nte->notes_list_store), &iter);
     }
 }
 
