@@ -93,8 +93,7 @@ notes_edit_action_cb (GtkWidget *widget, gpointer data) {
 GtkTreePath *path, *sort_path, *filter_path;
 GtkTreeIter iter;
 gchar *category;
-gboolean flag, remember_cursor;
-gint i, n;
+gboolean remember_cursor;
 
     GUI *appGUI = (GUI *)data;
 
@@ -110,27 +109,8 @@ gint i, n;
 
     if (path != NULL) {
 
-        n = gtk_combo_box_get_active (GTK_COMBO_BOX(appGUI->nte->category_combobox));
-
-        if (n == 0) { 
-            category = g_strdup(_("None"));
-        } else {
-            i = 0;
-            flag = FALSE;
-            while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->opt->notes_category_store), &iter, NULL, i++)) {
-                gtk_tree_model_get(GTK_TREE_MODEL(appGUI->opt->notes_category_store), &iter, 0, &category, -1);
-                if (i == n) {
-                    flag = TRUE;
-                    break;
-                }
-                g_free(category);
-            }
-            if (flag != TRUE) {
-                category = g_strdup(_("None"));
-            }
-        }
-
-		remember_cursor = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->nte->remember_cursor_checkbutton));
+        category = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(appGUI->nte->category_combobox));
+        remember_cursor = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->nte->remember_cursor_checkbutton));
 
         gtk_tree_model_get_iter (GTK_TREE_MODEL(appGUI->nte->notes_list_store), &iter, path);
         gtk_list_store_set(appGUI->nte->notes_list_store, &iter, 
@@ -192,10 +172,9 @@ notes_edit_dialog_show (GtkWidget *list, GtkTreeModel *model, GUI *appGUI)
 	GtkWidget *table;
 
 	GtkTreeIter iter;
-	gchar *c_category, *category, *name;
+	gchar *category, *name;
 	gchar tmpbuf[BUFFER_SIZE];
 	gboolean remember_cursor;
-	gint i, n;
 
 	appGUI->nte->edit_entry_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_container_set_border_width (GTK_CONTAINER (appGUI->nte->edit_entry_window), 4);
@@ -295,24 +274,20 @@ notes_edit_dialog_show (GtkWidget *list, GtkTreeModel *model, GUI *appGUI)
 	iter = utl_gui_get_first_selection_iter(appGUI->nte->notes_list_selection, &model);
 	gtk_tree_model_get(model, &iter,
                 N_COLUMN_NAME, &name,
-                N_COLUMN_CATEGORY, &c_category,
+                N_COLUMN_CATEGORY, &category,
                 N_COLUMN_REMEMBER_EDITOR_LINE, &remember_cursor,
                 -1);
 
 	gtk_entry_set_text(GTK_ENTRY(appGUI->nte->note_name_entry), name);
-	i = n = 0;
-
-	while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->opt->notes_category_store), &iter, NULL, i++)) {
-            gtk_tree_model_get(GTK_TREE_MODEL(appGUI->opt->notes_category_store), &iter, 0, &category, -1);
-            gtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(appGUI->nte->category_combobox), NULL, category);
-            if (!strcmp(category, c_category)) n = i;
-            g_free(category);
-	}
-	gtk_combo_box_set_active(GTK_COMBO_BOX(appGUI->nte->category_combobox), n);
+        
+        utl_gui_create_category_combobox(GTK_COMBO_BOX(appGUI->nte->category_combobox),
+            appGUI->opt->notes_category_store, TRUE);
+            
+	gtk_combo_box_set_active(GTK_COMBO_BOX(appGUI->nte->category_combobox), utl_gui_list_store_get_text_index(appGUI->opt->notes_category_store, category));
 
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(appGUI->nte->remember_cursor_checkbutton), remember_cursor);
 
-	g_free(c_category);
+	g_free(category);
 	g_free(name);
 	gtk_widget_show_all(appGUI->nte->edit_entry_window);
 }
@@ -411,8 +386,7 @@ gchar *category, *create_date_str;
 guint32 current_date;
 GtkTreeIter iter;
 gint current_time;
-gint i, n;
-gboolean flag, remember_cursor;
+gboolean remember_cursor;
 
 #ifdef HAVE_LIBGRINGOTTS
 gchar *pass = NULL, *spass = NULL;
@@ -438,7 +412,7 @@ GRG_KEY keyholder;
 #endif /* HAVE_LIBGRINGOTTS */
 
     name = g_strdup(gtk_entry_get_text(GTK_ENTRY(appGUI->nte->note_name_entry)));
-    n = gtk_combo_box_get_active (GTK_COMBO_BOX(appGUI->nte->category_combobox));
+    category = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(appGUI->nte->category_combobox));
 	remember_cursor = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->nte->remember_cursor_checkbutton));
 
     notes_add_close_cb (NULL, NULL, appGUI);
@@ -471,24 +445,6 @@ GRG_KEY keyholder;
 							 "", 0, NULL);
 	}
 #endif /* HAVE_LIBGRINGOTTS */
-
-        if (n == 0) { 
-            category = g_strdup(_("None"));
-        } else {
-            i = 0;
-            flag = FALSE;
-            while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->opt->notes_category_store), &iter, NULL, i++)) {
-                gtk_tree_model_get(GTK_TREE_MODEL(appGUI->opt->notes_category_store), &iter, 0, &category, -1);
-                if (i == n) {
-                    flag = TRUE;
-                    break;
-                }
-                g_free(category);
-            }
-            if (flag != TRUE) {
-                category = g_strdup(_("None"));
-            }
-        }
         create_date_str = g_strdup(get_date_time_str (current_date, current_time));
 
         gtk_list_store_append(appGUI->nte->notes_list_store, &iter);
@@ -580,7 +536,7 @@ GSList *note_normal_radiobutton_group = NULL;
 #endif  /* HAVE_LIBGRINGOTTS */
 
 gchar tmpbuf[BUFFER_SIZE];
-gint i;
+gboolean has_next;
 gchar *category;
 GtkTreeIter iter;
 
@@ -646,12 +602,12 @@ GtkTreeIter iter;
     gtk_widget_set_margin_bottom(appGUI->nte->category_combobox, 4);
     gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (appGUI->nte->category_combobox), NULL, _("None"));
 
-    i = 0;
-
-    while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->opt->notes_category_store), &iter, NULL, i++)) {
+    has_next = gtk_tree_model_get_iter_first (GTK_TREE_MODEL(appGUI->opt->notes_category_store), &iter);
+    while (has_next) {
         gtk_tree_model_get(GTK_TREE_MODEL(appGUI->opt->notes_category_store), &iter, 0, &category, -1);
         gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (appGUI->nte->category_combobox), NULL, category);
         g_free(category);
+        has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL(appGUI->opt->notes_category_store), &iter);
     }
 
     gtk_combo_box_set_active (GTK_COMBO_BOX(appGUI->nte->category_combobox), 
@@ -903,6 +859,10 @@ gint ret;
         appGUI->nte->buffer_check_modify_enable = TRUE;
     }
 
+    if(txtnote) {
+        grg_free(appGUI->nte->context, txtnote, txtlen);
+    }
+
     g_free(current_filename);
     g_free(pass);
 }
@@ -1228,7 +1188,6 @@ gboolean remember_editor_line, editor_readonly;
 void
 write_notes_entries (GUI *appGUI) {
 
-gint i;
 xmlDocPtr doc;
 xmlNodePtr main_node, node, note_node;
 xmlAttrPtr attr;
@@ -1236,7 +1195,7 @@ GtkTreeIter iter;
 gchar *category, *name, *note_filename, *note_fontname;
 gint last_changes_time, create_time, editor_line;
 guint32 last_changes_date_julian, create_date_julian;
-gboolean remember_editor_line, editor_readonly;
+gboolean remember_editor_line, editor_readonly, has_next;
 xmlChar *escaped;
 
     if ((appGUI->save_status & WRT_NOTES) != 0) return;
@@ -1251,22 +1210,21 @@ xmlChar *escaped;
 
     node = xmlNewChild(main_node, NULL, (const xmlChar *) NOTES_CATEGORY_ENTRIES_NAME, (xmlChar *) NULL);
 
-    i = 0;
-
-    while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->opt->notes_category_store), &iter, NULL, i++)) {
+    has_next = gtk_tree_model_get_iter_first (GTK_TREE_MODEL(appGUI->opt->notes_category_store), &iter);
+    while (has_next) {
 
         gtk_tree_model_get(GTK_TREE_MODEL(appGUI->opt->notes_category_store), &iter, 0, &category, -1);
 		escaped = xmlEncodeEntitiesReentrant(doc, (const xmlChar *) category);
         xmlNewChild(node, NULL, (const xmlChar *) "name", (xmlChar *) escaped);
         g_free(category);
         xmlFree (escaped);
+        has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL(appGUI->opt->notes_category_store), &iter);
     }
 
     node = xmlNewChild(main_node, NULL, (const xmlChar *) NOTES_ENTRIES_NAME, (xmlChar *) NULL);
 
-    i = 0;
-
-	while (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (appGUI->nte->notes_list_store), &iter, NULL, i++)) {
+    has_next = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (appGUI->nte->notes_list_store), &iter);
+    	while (has_next) {
 
 		gtk_tree_model_get (GTK_TREE_MODEL (appGUI->nte->notes_list_store), &iter,
 		                    N_COLUMN_NAME, &name,
@@ -1295,8 +1253,10 @@ xmlChar *escaped;
 		utl_xml_put_int ("editor_line", editor_line, note_node);
 		utl_xml_put_int ("read_only", editor_readonly, note_node);
 		utl_xml_put_str ("fontname", note_fontname, note_node);
+		g_free (note_fontname);
 		utl_xml_put_str ("filename", note_filename, note_node);
 		g_free (note_filename);
+                has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (appGUI->nte->notes_list_store), &iter);
 	}
 
 	utl_xml_write_doc (prefs_get_data_filename (NOTES_ENTRIES_FILENAME, appGUI), doc);
@@ -1333,7 +1293,6 @@ notes_cleanup_files (GUI *appGUI) {
 gchar fullpath[PATH_MAX];
 GDir *dpath;
 gboolean found;
-gint i;
 const gchar *item_name;
 gchar *note_filename;
 GtkTreeIter iter;
@@ -1344,15 +1303,15 @@ GtkTreeIter iter;
     if (dpath != NULL) {
 
         while ((item_name = g_dir_read_name (dpath)) != NULL) {
+            gboolean has_next;
 
             found = FALSE;
 
             g_snprintf(fullpath, PATH_MAX-1, "%s%c%s", 
                        prefs_get_data_filename(NOTES_DIRNAME, appGUI), G_DIR_SEPARATOR, item_name);
 
-            i = 0;
-
-            while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->nte->notes_list_store), &iter, NULL, i++)) {
+            has_next = gtk_tree_model_get_iter_first (GTK_TREE_MODEL(appGUI->nte->notes_list_store), &iter);
+            while (has_next) {
 
                 gtk_tree_model_get(GTK_TREE_MODEL(appGUI->nte->notes_list_store), &iter, 
                                    N_COLUMN_FILENAME, &note_filename, -1);
@@ -1364,6 +1323,7 @@ GtkTreeIter iter;
                 }
 
                 g_free(note_filename);
+                has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL(appGUI->nte->notes_list_store), &iter);
             }
 
             if (found == FALSE) {
