@@ -266,24 +266,23 @@ notes_category_add_cb (GtkWidget *widget, GUI *appGUI)
 	GtkTreeIter iter;
 	const gchar *category_name;
 	gchar *item;
-	gint i;
+	gboolean has_next;
 
 	category_name = gtk_entry_get_text (GTK_ENTRY (appGUI->opt->notes_category_entry));
 	if (!strlen (category_name)) return;
 
-	i = 0;
-
-	while (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store), &iter, NULL, i++)) {
+	
+        has_next = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (store), &iter);
+	while (has_next) {
 		gtk_tree_model_get (GTK_TREE_MODEL (store), &iter, 0, &item, -1);
 		if (!strcmp (category_name, item)) {
 			g_free (item);
 			return;
 		}
 		g_free (item);
+                has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (store), &iter);
 	}
 
-	gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store), &iter, NULL, 0);
-
 	gtk_list_store_append (store, &iter);
 	gtk_list_store_set (store, &iter, 0, category_name, -1);
 	gtk_entry_set_text (GTK_ENTRY (appGUI->opt->notes_category_entry), "");
