@@ -898,7 +898,7 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 
 	/*---------------------------------------------------------------------------------------*/
 
-	xmlSaveFormatFile (prefs_get_config_filename (CONFIG_FILENAME, appGUI), doc, 1);
+	utl_xml_write_doc (prefs_get_config_filename (CONFIG_FILENAME, appGUI), doc);
 	xmlFreeDoc (doc);
 }
 /*------------------------------------------------------------------------------*/
