@@ -25,6 +25,8 @@
 #include "gui.h"
 
 GtkWidget * opt_create_preferences_window (GUI *appGUI);
+void        opt_hide_modules (gboolean cal, gboolean tsk, gboolean cnt, gboolean nte, 
+							  gboolean options, GUI *appGUI);
 
 #endif /* _PREFERENCES_GUI_H */
 
