@@ -601,7 +601,7 @@ set_categories (GUI *appGUI)
 {
 	GtkTreeIter iter;
 	gchar *category;
-	gboolean tasks_state;
+	gboolean tasks_state, has_next;
 	gint i, n;
 
 	n = utl_gui_get_combobox_items (GTK_COMBO_BOX (appGUI->tsk->cf_combobox));
@@ -611,9 +611,8 @@ set_categories (GUI *appGUI)
 
 	gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (appGUI->tsk->cf_combobox), NULL, _("All items"));
 
-	i = 0;
-
-	while (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (appGUI->opt->tasks_category_store), &iter, NULL, i++))
+	has_next = gtk_tree_model_get_iter_first(GTK_TREE_MODEL (appGUI->opt->tasks_category_store), &iter);
+	while (has_next)
 	{
 		gtk_tree_model_get (GTK_TREE_MODEL (appGUI->opt->tasks_category_store), &iter,
 		                    TC_COLUMN_NAME, &category,
@@ -623,6 +622,7 @@ set_categories (GUI *appGUI)
 			gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (appGUI->tsk->cf_combobox), NULL, category);
 
 		g_free (category);
+                has_next = gtk_tree_model_iter_next(GTK_TREE_MODEL (appGUI->opt->tasks_category_store), &iter);
 	}
 	
 	if (config.remember_category_in_tasks == TRUE)
@@ -637,12 +637,13 @@ void
 refresh_tasks (GUI *appGUI)
 {
 	GtkTreeIter iter;
-	gint i = 0, due_time;
+	gint due_time;
 	guint32 julian_day;
 	gchar *priority;
-	gboolean done;
-
-	while (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (appGUI->tsk->tasks_list_store), &iter, NULL, i++))
+	gboolean done, has_next;
+        
+        has_next = gtk_tree_model_get_iter_first(GTK_TREE_MODEL (appGUI->tsk->tasks_list_store), &iter);
+	while (has_next)
 	{
 		gtk_tree_model_get (GTK_TREE_MODEL (appGUI->tsk->tasks_list_store), &iter,
 		                    TA_COLUMN_DONE, &done,
@@ -666,6 +667,7 @@ refresh_tasks (GUI *appGUI)
 		}
 
 		g_free (priority);
+                has_next = gtk_tree_model_iter_next(GTK_TREE_MODEL (appGUI->tsk->tasks_list_store), &iter);
 	}
 }
 
@@ -1102,7 +1104,6 @@ tasks_search_entry_changed_cb (GtkEditable *editable, gpointer user_data)
 {
 	GtkTreePath *path;
 	GtkTreeIter iter;
-	gint i;
 
 	GUI *appGUI = (GUI *) user_data;
 
@@ -1110,10 +1111,8 @@ tasks_search_entry_changed_cb (GtkEditable *editable, gpointer user_data)
 
 	if (g_utf8_strlen (gtk_entry_get_text (GTK_ENTRY (appGUI->tsk->tasks_find_entry)), -1))
 	{
-		i = 0;
-		while (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (appGUI->tsk->tasks_filter), &iter, NULL, i++));
-
-		if (i-1 != 0)
+		gboolean has_next = gtk_tree_model_get_iter_first(GTK_TREE_MODEL (appGUI->tsk->tasks_filter), &iter);
+		if (has_next)
 		{
 			path = gtk_tree_path_new_first ();
 			if (path != NULL)
@@ -1410,6 +1409,7 @@ gui_create_tasks (GUI *appGUI)
 	appGUI->tsk->tasks_sort = gtk_tree_model_sort_new_with_model (GTK_TREE_MODEL (appGUI->tsk->tasks_filter));
 
 	appGUI->tsk->tasks_list = gtk_tree_view_new_with_model (GTK_TREE_MODEL (appGUI->tsk->tasks_sort));
+	gtk_tree_view_set_enable_search (GTK_TREE_VIEW (appGUI->tsk->tasks_list), FALSE);
 	gtk_widget_show (appGUI->tsk->tasks_list);
 
 	g_signal_connect (G_OBJECT (appGUI->tsk->tasks_list), "button_press_event",
@@ -1737,9 +1737,7 @@ gui_create_tasks (GUI *appGUI)
 
 	set_tasks_columns_width (appGUI);
 
-	/* configure list options */
 	gtk_container_add (GTK_CONTAINER (appGUI->tsk->scrolled_win), appGUI->tsk->tasks_list);
-	gtk_tree_view_set_enable_search (GTK_TREE_VIEW (appGUI->tsk->tasks_list), FALSE);
 
 	/* configure sorting */
 	for (i = 0; i < MAX_VISIBLE_TASK_COLUMNS; i++) {
