@@ -46,8 +46,8 @@ gint day, month, year, due_time;
 guint32 julian_day;
 gchar *filename, *summary, *date, *priority, *description, *category;
 GtkWidget *dialog;
-GtkTreePath *sort_path, *filter_path, *path;
-GtkTreeIter iter;
+GtkTreeIter sort_iter;
+gboolean valid;
 icalset *ics_file;
 struct icaltimetype atime;
 icalcomponent *event, *calendar;
@@ -93,96 +93,81 @@ icalproperty *prop;
     prop = icalproperty_new_version (VERSION);
     icalcomponent_add_property (calendar, prop);
 
-	sort_path = gtk_tree_path_new_first ();
-	n = 0;
+    valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(appGUI->tsk->tasks_sort), &sort_iter);
+    n = 0;
 
-	while (gtk_tree_model_get_iter (GTK_TREE_MODEL (appGUI->tsk->tasks_list_store), &iter, sort_path) == TRUE) {
+    while (valid) {
+        GtkTreeIter filter_iter, iter;
+        gtk_tree_model_sort_convert_iter_to_child_iter(GTK_TREE_MODEL_SORT(appGUI->tsk->tasks_sort), &filter_iter, &sort_iter);
+        gtk_tree_model_filter_convert_iter_to_child_iter(GTK_TREE_MODEL_FILTER(appGUI->tsk->tasks_filter), &iter, &filter_iter);
+        gtk_tree_model_get(GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter,
+                TA_COLUMN_SUMMARY, &summary,
+                TA_COLUMN_DESCRIPTION, &description,
+                TA_COLUMN_CATEGORY, &category,
+                TA_COLUMN_DUE_DATE, &date,
+                TA_COLUMN_DUE_TIME, &due_time,
+                TA_COLUMN_DUE_DATE_JULIAN, &julian_day,
+                TA_COLUMN_PRIORITY, &priority,
+                -1);
 
-		if (sort_path != NULL) {
-			filter_path = gtk_tree_model_sort_convert_path_to_child_path (GTK_TREE_MODEL_SORT (appGUI->tsk->tasks_sort), sort_path);
+        if (julian_day != 0) {
 
-			if (filter_path != NULL) {
-				path = gtk_tree_model_filter_convert_path_to_child_path (GTK_TREE_MODEL_FILTER (appGUI->tsk->tasks_filter), filter_path);
+            event = icalcomponent_new(ICAL_VEVENT_COMPONENT);
 
-				if (path != NULL) {
+            utl_date_julian_to_dmy(julian_day, &day, &month, &year);
+            atime.day = day;
+            atime.month = month;
+            atime.year = year;
+            if (due_time == -1) {
+                atime.is_date = TRUE;
+            } else {
+                atime.hour = due_time / 3600;
+                atime.minute = (due_time % 3600) / 60;
+                atime.second = 0;
+                atime.is_date = FALSE;
+            }
 
-					gtk_tree_model_get_iter (GTK_TREE_MODEL (appGUI->tsk->tasks_list_store), &iter, path);
-					gtk_tree_model_get (GTK_TREE_MODEL (appGUI->tsk->tasks_list_store), &iter,
-										TA_COLUMN_SUMMARY, &summary,
-										TA_COLUMN_DESCRIPTION, &description,
-										TA_COLUMN_CATEGORY, &category,
-										TA_COLUMN_DUE_DATE, &date,
-										TA_COLUMN_DUE_TIME, &due_time,
-										TA_COLUMN_DUE_DATE_JULIAN, &julian_day,
-										TA_COLUMN_PRIORITY, &priority,
-										-1);
+            g_snprintf(tmpbuf, BUFFER_SIZE, "id%d%d%d%d@clayo.org", year, month, day, n);
+            prop = icalproperty_new_uid(tmpbuf);
+            icalcomponent_add_property(event, prop);
+            icalproperty_free(prop);
+            prop = icalproperty_new_priority(tsk_get_priority_index(priority));
+            icalcomponent_add_property(event, prop);
+            icalproperty_free(prop);
 
-					if (julian_day != 0) {
+            if (g_utf8_collate(category, _("None"))) {
+                prop = icalproperty_new_categories(category);
+                icalcomponent_add_property(event, prop);
+                icalproperty_free(prop);
+            }
 
-						event = icalcomponent_new (ICAL_VEVENT_COMPONENT);
+            prop = icalproperty_new_summary(summary);
+            icalcomponent_add_property(event, prop);
+            icalproperty_free(prop);
+            prop = icalproperty_new_description(description);
+            icalcomponent_add_property(event, prop);
+            icalproperty_free(prop);
+            prop = icalproperty_new_dtstamp(atime);
+            icalcomponent_add_property(event, prop);
+            icalproperty_free(prop);
+            prop = icalproperty_new_dtstart(atime);
+            icalcomponent_add_property(event, prop);
+            icalproperty_free(prop);
+            prop = icalproperty_new_dtend(atime);
+            icalcomponent_add_property(event, prop);
+            icalproperty_free(prop);
 
-						utl_date_julian_to_dmy (julian_day, &day, &month, &year);
-						atime.day = day;
-						atime.month = month;
-						atime.year = year;
-						if (due_time == -1) {
-							atime.is_date = TRUE;
-						} else {
-							atime.hour = due_time / 3600;
-							atime.minute = (due_time % 3600) / 60;
-							atime.second = 0;
-							atime.is_date = FALSE;
-						}
+            icalcomponent_add_component(calendar, event);
 
-						g_snprintf (tmpbuf, BUFFER_SIZE, "id%d%d%d%d@clayo.org", year, month, day, n);
-						prop = icalproperty_new_uid (tmpbuf);
-						icalcomponent_add_property (event, prop);
-						icalproperty_free (prop);
-						prop = icalproperty_new_priority (tsk_get_priority_index(priority));
-						icalcomponent_add_property (event, prop);
-						icalproperty_free (prop);
+            icalcomponent_free(event);
+            g_free(summary);
+            g_free(description);
+            g_free(category);
 
-                        if (g_utf8_collate(category, _("None"))) {
-							prop = icalproperty_new_categories (category);
-							icalcomponent_add_property (event, prop);
-							icalproperty_free (prop);
-						}
-
-						prop = icalproperty_new_summary (summary);
-						icalcomponent_add_property (event, prop);
-						icalproperty_free (prop);
-						prop = icalproperty_new_description (description);
-						icalcomponent_add_property (event, prop);
-						icalproperty_free (prop);
-						prop = icalproperty_new_dtstamp (atime);
-						icalcomponent_add_property (event, prop);
-						icalproperty_free (prop);
-						prop = icalproperty_new_dtstart (atime);
-						icalcomponent_add_property (event, prop);
-						icalproperty_free (prop);
-						prop = icalproperty_new_dtend (atime);
-						icalcomponent_add_property (event, prop);
-						icalproperty_free (prop);
-
-						icalcomponent_add_component (calendar, event);
-
-						icalcomponent_free (event);
-						g_free (summary);
-						g_free (description);
-						g_free (category);
-
-						n++;
-					}
-					gtk_tree_path_free (path);
-				}
-
-				gtk_tree_path_free (filter_path);
-			}
-
-		}
-
-		gtk_tree_path_next (sort_path);
-	}
+            n++;
+        }
+        valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(appGUI->tsk->tasks_sort), &sort_iter);
+    }
 
     icalset_add_component (ics_file, calendar);
     icalfileset_commit (ics_file);
