@@ -124,10 +124,10 @@ gchar tmpbuf[BUFFER_SIZE];
     item->repeat_month_interval = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(appGUI->tsk->rt_dp_month_spinbutton));
     item->repeat_counter = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(appGUI->tsk->repeat_counter_spinbutton));
 
-    item->priority = g_strdup(gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(appGUI->tsk->priority_combobox)));
-    item->category = g_strdup(gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(appGUI->tsk->category_combobox)));
+    item->priority = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(appGUI->tsk->priority_combobox));
+    item->category = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(appGUI->tsk->category_combobox));
     item->summary = g_strdup((gchar *) gtk_entry_get_text(GTK_ENTRY(appGUI->tsk->summary_entry)));
-    item->desc = g_strdup(gtk_text_buffer_get_text(GTK_TEXT_BUFFER(text_buffer), &iter_a, &iter_b, TRUE));
+    item->desc = gtk_text_buffer_get_text(GTK_TEXT_BUFFER(text_buffer), &iter_a, &iter_b, TRUE);
 
 	if (g_date_valid_julian (item->due_date_julian)) {
 		cdate = g_date_new_julian (item->due_date_julian);
@@ -629,6 +629,7 @@ create_basic_tab(GUI *appGUI) {
     GtkWidget *label;
     GtkWidget *select_date_button;
     GtkWidget *scrolledwindow;
+    gchar *category;
 
     grid = gtk_grid_new();
     gtk_grid_set_row_spacing(GTK_GRID(grid), 6);
@@ -669,9 +670,10 @@ create_basic_tab(GUI *appGUI) {
     gtk_grid_attach(GTK_GRID(grid), appGUI->tsk->category_combobox, 1, 2, 2, 1);
     utl_gui_create_category_combobox(GTK_COMBO_BOX(appGUI->tsk->category_combobox),
             appGUI->opt->tasks_category_store, TRUE);
+    category = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(appGUI->tsk->cf_combobox));
     gtk_combo_box_set_active(GTK_COMBO_BOX(appGUI->tsk->category_combobox),
-            utl_gui_list_store_get_text_index(appGUI->opt->tasks_category_store,
-            gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(appGUI->tsk->cf_combobox))));
+            utl_gui_list_store_get_text_index(appGUI->opt->tasks_category_store, category));
+    g_free(category);
 
     label = create_styled_label("<b>%s:</b>", _("Priority"));
     gtk_widget_set_halign(label, GTK_ALIGN_START);
@@ -1505,7 +1507,7 @@ gchar *name;
 gint tc_calendar, tc_tasks;
 TASK_ITEM *item;
 gchar temp[BUFFER_SIZE];
-gint i;
+gboolean has_next;
 xmlChar *escaped;
 
 	if ((appGUI->save_status & WRT_TASKS) != 0) return;
@@ -1522,9 +1524,8 @@ xmlChar *escaped;
 
 	node = xmlNewChild (main_node, NULL, (const xmlChar *) TASKS_CATEGORY_ENTRIES_NAME, (xmlChar *) NULL);
 
-	i = 0;
-
-	while (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (appGUI->opt->tasks_category_store), &iter, NULL, i++)) {
+	has_next = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (appGUI->opt->tasks_category_store), &iter);
+	while (has_next) {
 		gtk_tree_model_get (GTK_TREE_MODEL (appGUI->opt->tasks_category_store), &iter,
 		                    TC_COLUMN_NAME, &name, TC_COLUMN_CALENDAR, &tc_calendar, TC_COLUMN_TASKS, &tc_tasks, -1);
 
@@ -1542,13 +1543,13 @@ xmlChar *escaped;
         xmlFree (escaped);
 
 		g_free (name);
+                has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (appGUI->opt->tasks_category_store), &iter);
 	}
 
 	node = xmlNewChild (main_node, NULL, (const xmlChar *) TASKS_ENTRIES_NAME, (xmlChar *) NULL);
 
-	i = 0;
-
-	while (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (appGUI->tsk->tasks_list_store), &iter, NULL, i++)) {
+	has_next = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (appGUI->tsk->tasks_list_store), &iter);
+	while (has_next) {
 		item = tsk_get_item (&iter, appGUI);
 
 		if (item != NULL) {
@@ -1584,6 +1585,7 @@ xmlChar *escaped;
 
 			tsk_item_free (item);
 		}
+                has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (appGUI->tsk->tasks_list_store), &iter);
 	}
 
 	utl_xml_write_doc (prefs_get_data_filename (TASKS_ENTRIES_FILENAME, appGUI), doc);
