@@ -262,23 +262,22 @@ tasks_category_add_cb (GtkWidget *widget, GUI *appGUI)
 	GtkTreeIter iter;
 	const gchar *category_name;
 	gchar *item;
-	gint i;
+	gboolean has_next;
 
 	category_name = gtk_entry_get_text (GTK_ENTRY (appGUI->opt->tasks_category_entry));
 	if (!strlen (category_name)) return;
 
-	i = 0;
-	while (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (appGUI->opt->tasks_category_store), &iter, NULL, i++)) {
+	has_next = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (appGUI->opt->tasks_category_store), &iter);
+	while (has_next) {
 		gtk_tree_model_get (GTK_TREE_MODEL (appGUI->opt->tasks_category_store), &iter, TC_COLUMN_NAME, &item, -1);
 		if (!strcmp (category_name, item)) {
 			g_free (item);
 			return;
 		}
 		g_free (item);
+                has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL (appGUI->opt->tasks_category_store), &iter);
 	}
 
-	gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (appGUI->opt->tasks_category_store), &iter, NULL, 0);
-
 	gtk_list_store_append (appGUI->opt->tasks_category_store, &iter);
 	gtk_list_store_set (appGUI->opt->tasks_category_store, &iter,
 	                    TC_COLUMN_NAME, category_name,
@@ -521,16 +520,15 @@ create_tasks_options_section (GtkWidget *tasks_opt_vbox, GUI *appGUI)
 	                  &(config.remember_category_in_tasks));
 	appGUI->opt->ct_remember_category_checkbutton = checkbutton;
 }
-
 /* ========================================================================== */
 
 static gint
-global_notification_entry_changed_cb (GtkEditable *editable, GUI *appGUI)
-{
-	utl_gui_update_command_status (editable, appGUI->opt->global_notification_valid_image, appGUI);
-	g_strlcpy (config.global_notification_command, gtk_editable_get_chars (editable, 0, -1), MAXHELPERCMD);
-
-	return FALSE;
+global_notification_entry_changed_cb(GtkEditable *editable, GUI *appGUI) {
+    gchar *text = gtk_editable_get_chars(editable, 0, -1);
+    utl_gui_update_command_status(editable, appGUI->opt->global_notification_valid_image, appGUI);
+    g_strlcpy(config.global_notification_command, text, MAXHELPERCMD);
+    g_free(text);
+    return FALSE;
 }
 
 /* ========================================================================== */
