@@ -76,8 +76,8 @@ tasks_draw_page (GtkPrintOperation *operation, GtkPrintContext *context, gint np
 {
 	PangoLayout *layout;
 	PangoFontDescription *desc;
-	GtkTreePath *sort_path, *filter_path, *path;
-	GtkTreeIter iter;
+	GtkTreeIter sort_iter;
+        gboolean valid;
 	cairo_t *cr;
 	gchar *summary, *date, *priority;
 	gchar buffer[BUFFER_SIZE];
@@ -158,74 +158,60 @@ tasks_draw_page (GtkPrintOperation *operation, GtkPrintContext *context, gint np
 
 	ycursor += 0.7 * task_height;
 
-	sort_path = gtk_tree_path_new_first ();
+	valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(appGUI->tsk->tasks_sort), &sort_iter);
 
 	i = 0;
 	imin = appGUI->print_lines_per_page * npage;
 	imax = appGUI->print_lines_per_page * (npage + 1);
 
-	while (gtk_tree_model_get_iter (GTK_TREE_MODEL (appGUI->tsk->tasks_list_store), &iter, sort_path) == TRUE) {
+        while (valid) {
+            if (i >= imin && i < imax) {
+                GtkTreeIter filter_iter, iter;
+                gtk_tree_model_sort_convert_iter_to_child_iter(GTK_TREE_MODEL_SORT(appGUI->tsk->tasks_sort), &filter_iter, &sort_iter);
+                gtk_tree_model_filter_convert_iter_to_child_iter(GTK_TREE_MODEL_FILTER(appGUI->tsk->tasks_filter), &iter, &filter_iter);
+                gtk_tree_model_get(GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter,
+                        TA_COLUMN_SUMMARY, &summary,
+                        TA_COLUMN_DUE_DATE, &date,
+                        TA_COLUMN_PRIORITY, &priority,
+                        -1);
 
-		if (sort_path != NULL) {
-			filter_path = gtk_tree_model_sort_convert_path_to_child_path (GTK_TREE_MODEL_SORT (appGUI->tsk->tasks_sort), sort_path);
+                ycursor += 0.3 * task_height;
 
-			if (filter_path != NULL) {
-				path = gtk_tree_model_filter_convert_path_to_child_path (GTK_TREE_MODEL_FILTER (appGUI->tsk->tasks_filter), filter_path);
+                g_snprintf(buffer, BUFFER_SIZE, "%d.", i + 1);
+                pango_layout_set_markup(layout, buffer, -1);
+                pango_layout_get_pixel_size(layout, &text_width, &text_height);
+                cairo_move_to(cr, 0.05 * page_width - text_width, ycursor);
+                pango_cairo_show_layout(cr, layout);
 
-				if (path != NULL) {
-					if (i >= imin && i < imax) {
-						gtk_tree_model_get_iter (GTK_TREE_MODEL (appGUI->tsk->tasks_list_store), &iter, path);
-						gtk_tree_model_get (GTK_TREE_MODEL (appGUI->tsk->tasks_list_store), &iter,
-						                    TA_COLUMN_SUMMARY, &summary,
-						                    TA_COLUMN_DUE_DATE, &date,
-						                    TA_COLUMN_PRIORITY, &priority,
-						                    -1);
+                g_snprintf(buffer, BUFFER_SIZE, "%.52s", summary);
+                pango_layout_set_text(layout, buffer, -1);
+                pango_layout_get_pixel_size(layout, &text_width, &text_height);
+                cairo_move_to(cr, 0.07 * page_width, ycursor);
+                pango_cairo_show_layout(cr, layout);
 
-						ycursor += 0.3 * task_height;
+                pango_layout_set_text(layout, date, -1);
+                pango_layout_get_pixel_size(layout, &text_width, &text_height);
+                cairo_move_to(cr, 0.66 * page_width, ycursor);
+                pango_cairo_show_layout(cr, layout);
 
-						g_snprintf (buffer, BUFFER_SIZE, "%d.", i + 1);
-						pango_layout_set_markup (layout, buffer, -1);
-						pango_layout_get_pixel_size (layout, &text_width, &text_height);
-						cairo_move_to (cr, 0.05 * page_width - text_width, ycursor);
-						pango_cairo_show_layout (cr, layout);
+                pango_layout_set_text(layout, priority, -1);
+                pango_layout_get_pixel_size(layout, &text_width, &text_height);
+                cairo_move_to(cr, 0.88 * page_width, ycursor);
+                pango_cairo_show_layout(cr, layout);
 
-						g_snprintf (buffer, BUFFER_SIZE, "%.52s", summary);
-						pango_layout_set_text (layout, buffer, -1);
-						pango_layout_get_pixel_size (layout, &text_width, &text_height);
-						cairo_move_to (cr, 0.07 * page_width, ycursor);
-						pango_cairo_show_layout (cr, layout);
+                ycursor += 0.7 * task_height;
+                cairo_move_to(cr, 0, ycursor);
+                cairo_line_to(cr, page_width, ycursor);
+                cairo_stroke(cr);
 
-						pango_layout_set_text (layout, date, -1);
-						pango_layout_get_pixel_size (layout, &text_width, &text_height);
-						cairo_move_to (cr, 0.66 * page_width, ycursor);
-						pango_cairo_show_layout (cr, layout);
+                g_free(summary);
+                g_free(date);
+                g_free(priority);
+            }
 
-						pango_layout_set_text (layout, priority, -1);
-						pango_layout_get_pixel_size (layout, &text_width, &text_height);
-						cairo_move_to (cr, 0.88 * page_width, ycursor);
-						pango_cairo_show_layout (cr, layout);
-
-						ycursor += 0.7 * task_height;
-						cairo_move_to (cr, 0, ycursor);
-						cairo_line_to (cr, page_width, ycursor);
-						cairo_stroke (cr);
-						
-						g_free (summary);
-						g_free (date);
-						g_free (priority);
-					}
-
-					i++;
-					gtk_tree_path_free (path);
-				}
-
-				gtk_tree_path_free (filter_path);
-			}
-
-		}
-
-		gtk_tree_path_next (sort_path);
-	}
+            i++;
+            valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(appGUI->tsk->tasks_sort), &sort_iter);
+        }
 
 	cairo_move_to (cr, 0, task_height);
 	cairo_line_to (cr, 0, ycursor);
