@@ -81,56 +81,6 @@ gint count, i;
 
 /*------------------------------------------------------------------------------*/
 
-gchar *     
-utl_inline_image_to_html (const guint8 *inline_data)
-{
-GdkPixbuf *image;
-gchar *output = g_strdup ("");
-gchar *img;
-gchar tmpbuf[BUFFER_SIZE];
-
-    image = gdk_pixbuf_new_from_inline (-1, inline_data, FALSE, NULL);
-
-    g_snprintf (tmpbuf, BUFFER_SIZE, "width=\"%d\" height=\"%d\">", 
-                gdk_pixbuf_get_width (image), gdk_pixbuf_get_height (image));
-
-    output = utl_strconcat (output, "<img src=\"data:image/png;base64,", NULL);
-    img = utl_inline_to_png_base64 (inline_data);
-    output = utl_strconcat (output, img, "\" ", tmpbuf, NULL);
-    g_free (img);
-
-    g_object_unref (image);
-
-    return output;
-}
-
-/*------------------------------------------------------------------------------*/
-
-gchar *     
-utl_inline_to_png_base64 (const guint8 *inline_data)
-{
-GdkPixbuf *image;
-gchar *buffer, *output;
-gsize bufferSize;
-GError *error = 0;
-
-    image = gdk_pixbuf_new_from_inline (-1, inline_data, FALSE, NULL);
-
-    if (!gdk_pixbuf_save_to_buffer(image, &buffer, &bufferSize, "png", &error, NULL)) {
-        g_error_free(error);
-        return NULL;
-    }
-
-    g_object_unref (image);
-
-    output = g_base64_encode ((const guchar *)buffer, bufferSize);
-    g_free (buffer);
-
-    return output;
-}
-
-/*------------------------------------------------------------------------------*/
-
 gchar *
 utl_text_replace (const gchar *text, const gchar *regex, const gchar *replacement)
 {
@@ -170,6 +120,7 @@ utl_webkit_link_clicked(WebKitWebView *web_view,
         WebKitPolicyDecisionType decision_type,
         gpointer user_data) {
     WebKitNavigationPolicyDecision *navigation_decision;
+    WebKitNavigationAction * navigation_action;
     WebKitNavigationType navigation_type;
     WebKitURIRequest *request;
     const gchar *uri;
@@ -181,11 +132,12 @@ utl_webkit_link_clicked(WebKitWebView *web_view,
     }
 
     navigation_decision = WEBKIT_NAVIGATION_POLICY_DECISION(decision);
-    navigation_type = webkit_navigation_policy_decision_get_navigation_type(navigation_decision);
+    navigation_action = webkit_navigation_policy_decision_get_navigation_action(navigation_decision);
+    navigation_type = webkit_navigation_action_get_navigation_type(navigation_action);
     if (navigation_type != WEBKIT_NAVIGATION_TYPE_LINK_CLICKED) {
         return FALSE;
     }
-    request = webkit_navigation_policy_decision_get_request(navigation_decision);
+    request = webkit_navigation_action_get_request (navigation_action);
     uri = webkit_uri_request_get_uri(request);
     webkit_policy_decision_ignore(decision);
 
@@ -738,7 +690,7 @@ gchar *found_path;
 
 void
 utl_run_command (gchar *command, gboolean sync) {
-
+GError *err = NULL;
 gchar *cmdline[4];
 
     cmdline[0] = "sh";
@@ -748,10 +700,14 @@ gchar *cmdline[4];
 
     if (sync == FALSE) {
         g_spawn_async (NULL, (gchar **)cmdline, NULL, G_SPAWN_SEARCH_PATH | G_SPAWN_STDOUT_TO_DEV_NULL, 
-                       NULL, NULL, NULL, NULL);
+                       NULL, NULL, NULL, &err);
     } else {
         g_spawn_sync (NULL, (gchar **)cmdline, NULL, G_SPAWN_SEARCH_PATH | G_SPAWN_STDOUT_TO_DEV_NULL, 
-                      NULL, NULL, NULL, NULL, NULL, NULL);
+                      NULL, NULL, NULL, NULL, NULL, &err);
+    }
+    if(err) {
+        fprintf(stderr, "Failed to execute command %s: %s", command, err->message);
+        g_error_free (err);
     }
 }
 
