@@ -78,8 +78,6 @@ void        utl_cairo_draw                      (cairo_t *cr, gint stroke);
 void        utl_draw_rounded_rectangle          (cairo_t *cr, gint x, gint y, gint w, gint h, gint a, gint s);
 void        utl_draw_left_arrow                 (cairo_t *cr, gdouble x, gdouble y, gdouble w, gdouble h, gdouble a);
 
-gchar *     utl_inline_to_png_base64            (const guint8 *inline_data);
-gchar *     utl_inline_image_to_html            (const guint8 *inline_data);
 gchar *     utl_text_with_tags_to_html          (gchar *input_text);
 
 void        utl_play_alarm_sound                (guint repetitions);
