@@ -238,6 +238,7 @@ utl_gui_create_category_combobox (GtkComboBox *combo_box, GtkListStore *store, g
 GtkTreeIter iter;
 gchar *category;
 gint i, n;
+gboolean has_next;
 
     n = utl_gui_get_combobox_items(combo_box);
 
@@ -253,13 +254,12 @@ gint i, n;
         gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combo_box), NULL, _("All items"));
     }
 
-    i = 0;
-
-    while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(store), &iter, NULL, i++)) {
-
+    has_next = gtk_tree_model_get_iter_first (GTK_TREE_MODEL(store), &iter);
+    while (has_next) {
         gtk_tree_model_get(GTK_TREE_MODEL(store), &iter, 0, &category, -1);
         gtk_combo_box_text_append (GTK_COMBO_BOX_TEXT (combo_box), NULL, category);
         g_free(category);
+        has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL(store), &iter);
     }
 
 }
@@ -647,10 +647,8 @@ GdkPixbuf *image;
 gchar *cmd;
 gint i;
 
-    if (strlen(gtk_editable_get_chars(editable, 0, -1))) {
-
-        cmd = g_strdup(gtk_editable_get_chars(editable, 0, -1));
-
+    cmd = gtk_editable_get_chars(editable, 0, -1);
+    if (cmd) {
         for (i=0; i < strlen(cmd); i++) {
             if (cmd[i] == ' ') cmd[i] = 0;
         }
@@ -665,7 +663,6 @@ gint i;
 	    gtk_image_set_from_pixbuf (GTK_IMAGE(icon_widget), image);
 	    g_object_unref (image);
         g_free (cmd);
-
     } else {
 	    gtk_widget_hide (icon_widget);
     }
@@ -708,32 +705,25 @@ utl_gui_clear_text_buffer (GtkTextBuffer *buffer, GtkTextIter *iter)
 
 gint
 utl_gui_list_store_get_text_index (GtkListStore *store, gchar *text) {
-
-GtkTreeIter iter;
-gint i, f;
-gchar *category;
-
-    i = f = 0;
-
     if (text != NULL) {
-        while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(store), &iter, NULL, i++)) {
-
-            gtk_tree_model_get(GTK_TREE_MODEL(store), &iter, 0, &category, -1);
-            if (category != NULL) {
-                if (!strcmp(category, text)) {
-                    f = 1;
-                    break;
+        GtkTreeIter iter;
+        gint i = 0;
+        gboolean has_next = gtk_tree_model_get_iter_first (GTK_TREE_MODEL(store), &iter);
+        while (has_next) {
+            gchar *value;
+            i++;
+            gtk_tree_model_get(GTK_TREE_MODEL(store), &iter, 0, &value, -1);
+            if (value != NULL) {
+                if (!strcmp(value, text)) {
+                    g_free(value);
+                    return i;
                 }
-                g_free(category);
+                g_free(value);
             }
-        }
-
-        if (f) {
-            g_free(category);
+            has_next = gtk_tree_model_iter_next (GTK_TREE_MODEL(store), &iter);
         }
     }
-
-    return (f ? i:0);
+    return 0;
 }
 
 /*------------------------------------------------------------------------------*/
@@ -795,7 +785,8 @@ GtkWidget *image;
 
 void
 utl_gui_url_initialize (GUI *appGUI) {
-    GdkDisplay *display = gdk_window_get_display(GDK_WINDOW(appGUI->main_window));
+    GdkWindow *window = gtk_widget_get_window(GTK_WIDGET(appGUI->main_window));
+    GdkDisplay *display = gdk_window_get_display(window);
 
     appGUI->hand_cursor = gdk_cursor_new_for_display (display, GDK_HAND2);
     appGUI->regular_cursor = gdk_cursor_new_for_display (display, GDK_XTERM);
